@@ -22,11 +22,11 @@ class DokuHTTPClient extends HTTPClient {
      *
      * @author Andreas Gohr <andi@splitbrain.org>
      */
-    function DokuHTTPClient(){
+    function __construct(){
         global $conf;
 
         // call parent constructor
-        $this->HTTPClient();
+        parent::__construct();
 
         // set some values from the config
         $this->proxy_host   = $conf['proxy']['host'];
@@ -61,6 +61,8 @@ class DokuHTTPClient extends HTTPClient {
 
 }
 
+class HTTPClientException extends Exception { }
+
 /**
  * This class implements a basic HTTP client
  *
@@ -121,7 +123,7 @@ class HTTPClient {
      *
      * @author Andreas Gohr <andi@splitbrain.org>
      */
-    function HTTPClient(){
+    function __construct(){
         $this->agent        = 'Mozilla/4.0 (compatible; DokuWiki HTTP Client; '.PHP_OS.')';
         $this->timeout      = 15;
         $this->cookies      = array();
@@ -148,6 +150,7 @@ class HTTPClient {
      *
      * @param  string $url       The URL to fetch
      * @param  bool   $sloppy304 Return body on 304 not modified
+     * @return bool|string  response body, false on error
      * @author Andreas Gohr <andi@splitbrain.org>
      */
     function get($url,$sloppy304=false){
@@ -168,6 +171,7 @@ class HTTPClient {
      * @param  string $url       The URL to fetch
      * @param  array  $data      Associative array of parameters
      * @param  bool   $sloppy304 Return body on 304 not modified
+     * @return bool|string  response body, false on error
      * @author Andreas Gohr <andi@splitbrain.org>
      */
     function dget($url,$data,$sloppy304=false){
@@ -185,6 +189,9 @@ class HTTPClient {
      *
      * Returns the resulting page or false on an error;
      *
+     * @param  string $url       The URL to fetch
+     * @param  array  $data      Associative array of parameters
+     * @return bool|string  response body, false on error
      * @author Andreas Gohr <andi@splitbrain.org>
      */
     function post($url,$data){
@@ -213,6 +220,9 @@ class HTTPClient {
         $this->start  = $this->_time();
         $this->error  = '';
         $this->status = 0;
+        $this->status = 0;
+        $this->resp_body = '';
+        $this->resp_headers = array();
 
         // don't accept gzip if truncated bodies might occur
         if($this->max_bodysize &&
@@ -227,7 +237,7 @@ class HTTPClient {
         $path   = $uri['path'];
         if(empty($path)) $path = '/';
         if(!empty($uri['query'])) $path .= '?'.$uri['query'];
-        if(isset($uri['port']) && !empty($uri['port'])) $port = $uri['port'];
+        if(!empty($uri['port'])) $port = $uri['port'];
         if(isset($uri['user'])) $this->user = $uri['user'];
         if(isset($uri['pass'])) $this->pass = $uri['pass'];
 
@@ -249,14 +259,10 @@ class HTTPClient {
         // prepare headers
         $headers               = $this->headers;
         $headers['Host']       = $uri['host'];
-        if($uri['port']) $headers['Host'].= ':'.$uri['port'];
+        if(!empty($uri['port'])) $headers['Host'].= ':'.$uri['port'];
         $headers['User-Agent'] = $this->agent;
         $headers['Referer']    = $this->referer;
-        if ($this->keep_alive) {
-            $headers['Connection'] = 'Keep-Alive';
-        } else {
-            $headers['Connection'] = 'Close';
-        }
+
         if($method == 'POST'){
             if(is_array($data)){
                 if($headers['Content-Type'] == 'multipart/form-data'){
@@ -279,16 +285,13 @@ class HTTPClient {
             $headers['Proxy-Authorization'] = 'Basic '.base64_encode($this->proxy_user.':'.$this->proxy_pass);
         }
 
-        // stop time
-        $start = time();
-
         // already connected?
         $connectionId = $this->_uniqueConnectionId($server,$port);
-        $this->_debug('connection pool', $this->connections);
+        $this->_debug('connection pool', self::$connections);
         $socket = null;
-        if (isset($this->connections[$connectionId])) {
+        if (isset(self::$connections[$connectionId])) {
             $this->_debug('reusing connection', $connectionId);
-            $socket = $this->connections[$connectionId];
+            $socket = self::$connections[$connectionId];
         }
         if (is_null($socket) || feof($socket)) {
             $this->_debug('opening connection', $connectionId);
@@ -300,224 +303,192 @@ class HTTPClient {
                 return false;
             }
 
+            // try establish a CONNECT tunnel for SSL
+            if($this->_ssltunnel($socket, $request_url)){
+                // no keep alive for tunnels
+                $this->keep_alive = false;
+                // tunnel is authed already
+                if(isset($headers['Proxy-Authentication'])) unset($headers['Proxy-Authentication']);
+            }
+
             // keep alive?
             if ($this->keep_alive) {
-                $this->connections[$connectionId] = $socket;
+                self::$connections[$connectionId] = $socket;
             } else {
-                unset($this->connections[$connectionId]);
+                unset(self::$connections[$connectionId]);
             }
         }
 
-        //set blocking
-        stream_set_blocking($socket,1);
-
-        // build request
-        $request  = "$method $request_url HTTP/".$this->http.HTTP_NL;
-        $request .= $this->_buildHeaders($headers);
-        $request .= $this->_getCookies();
-        $request .= HTTP_NL;
-        $request .= $data;
-
-        $this->_debug('request',$request);
-
-        // select parameters
-        $sel_r = null;
-        $sel_w = array($socket);
-        $sel_e = null;
-
-        // send request
-        $towrite = strlen($request);
-        $written = 0;
-        while($written < $towrite){
-            // check timeout
-            if(time()-$start > $this->timeout){
-                $this->status = -100;
-                $this->error = sprintf('Timeout while sending request (%.3fs)',$this->_time() - $this->start);
-                unset($this->connections[$connectionId]);
-                return false;
-            }
-
-            // wait for stream ready or timeout (1sec)
-            if(@stream_select($sel_r,$sel_w,$sel_e,1) === false){
-                usleep(1000);
-                continue;
-            }
-
-            // write to stream
-            $ret = fwrite($socket, substr($request,$written,4096));
-            if($ret === false){
-                $this->status = -100;
-                $this->error = 'Failed writing to socket';
-                unset($this->connections[$connectionId]);
-                return false;
-            }
-            $written += $ret;
+        if ($this->keep_alive && !$this->proxy_host) {
+            // RFC 2068, section 19.7.1: A client MUST NOT send the Keep-Alive
+            // connection token to a proxy server. We still do keep the connection the
+            // proxy alive (well except for CONNECT tunnels)
+            $headers['Connection'] = 'Keep-Alive';
+        } else {
+            $headers['Connection'] = 'Close';
         }
 
-        // continue non-blocking
-        stream_set_blocking($socket,0);
+        try {
+            //set non-blocking
+            stream_set_blocking($socket, false);
 
-        // read headers from socket
-        $r_headers = '';
-        do{
-            if(time()-$start > $this->timeout){
-                $this->status = -100;
-                $this->error = sprintf('Timeout while reading headers (%.3fs)',$this->_time() - $this->start);
-                unset($this->connections[$connectionId]);
-                return false;
-            }
-            if(feof($socket)){
-                $this->error = 'Premature End of File (socket)';
-                unset($this->connections[$connectionId]);
-                return false;
-            }
-            usleep(1000);
-            $r_headers .= fgets($socket,1024);
-        }while(!preg_match('/\r?\n\r?\n$/',$r_headers));
+            // build request
+            $request  = "$method $request_url HTTP/".$this->http.HTTP_NL;
+            $request .= $this->_buildHeaders($headers);
+            $request .= $this->_getCookies();
+            $request .= HTTP_NL;
+            $request .= $data;
 
-        $this->_debug('response headers',$r_headers);
+            $this->_debug('request',$request);
+            $this->_sendData($socket, $request, 'request');
 
-        // check if expected body size exceeds allowance
-        if($this->max_bodysize && preg_match('/\r?\nContent-Length:\s*(\d+)\r?\n/i',$r_headers,$match)){
-            if($match[1] > $this->max_bodysize){
-                $this->error = 'Reported content length exceeds allowed response size';
-                if ($this->max_bodysize_abort)
-                    unset($this->connections[$connectionId]);
-                    return false;
-            }
-        }
+            // read headers from socket
+            $r_headers = '';
+            do{
+                $r_line = $this->_readLine($socket, 'headers');
+                $r_headers .= $r_line;
+            }while($r_line != "\r\n" && $r_line != "\n");
 
-        // get Status
-        if (!preg_match('/^HTTP\/(\d\.\d)\s*(\d+).*?\n/', $r_headers, $m)) {
-            $this->error = 'Server returned bad answer';
-            unset($this->connections[$connectionId]);
-            return false;
-        }
-        $this->status = $m[2];
+            $this->_debug('response headers',$r_headers);
 
-        // handle headers and cookies
-        $this->resp_headers = $this->_parseHeaders($r_headers);
-        if(isset($this->resp_headers['set-cookie'])){
-            foreach ((array) $this->resp_headers['set-cookie'] as $cookie){
-                list($cookie)   = explode(';',$cookie,2);
-                list($key,$val) = explode('=',$cookie,2);
-                $key = trim($key);
-                if($val == 'deleted'){
-                    if(isset($this->cookies[$key])){
-                        unset($this->cookies[$key]);
-                    }
-                }elseif($key){
-                    $this->cookies[$key] = $val;
+            // check if expected body size exceeds allowance
+            if($this->max_bodysize && preg_match('/\r?\nContent-Length:\s*(\d+)\r?\n/i',$r_headers,$match)){
+                if($match[1] > $this->max_bodysize){
+                    if ($this->max_bodysize_abort)
+                        throw new HTTPClientException('Reported content length exceeds allowed response size');
+                    else
+                        $this->error = 'Reported content length exceeds allowed response size';
                 }
             }
-        }
 
-        $this->_debug('Object headers',$this->resp_headers);
+            // get Status
+            if (!preg_match('/^HTTP\/(\d\.\d)\s*(\d+).*?\n/', $r_headers, $m))
+                throw new HTTPClientException('Server returned bad answer');
 
-        // check server status code to follow redirect
-        if($this->status == 301 || $this->status == 302 ){
-            // close the connection because we don't handle content retrieval here
-            // that's the easiest way to clean up the connection
-            fclose($socket);
-            unset($this->connections[$connectionId]);
+            $this->status = $m[2];
 
-            if (empty($this->resp_headers['location'])){
-                $this->error = 'Redirect but no Location Header found';
-                return false;
-            }elseif($this->redirect_count == $this->max_redirect){
-                $this->error = 'Maximum number of redirects exceeded';
-                return false;
-            }else{
-                $this->redirect_count++;
-                $this->referer = $url;
-                // handle non-RFC-compliant relative redirects
-                if (!preg_match('/^http/i', $this->resp_headers['location'])){
-                    if($this->resp_headers['location'][0] != '/'){
-                        $this->resp_headers['location'] = $uri['scheme'].'://'.$uri['host'].':'.$uri['port'].
-                                                          dirname($uri['path']).'/'.$this->resp_headers['location'];
-                    }else{
-                        $this->resp_headers['location'] = $uri['scheme'].'://'.$uri['host'].':'.$uri['port'].
-                                                          $this->resp_headers['location'];
+            // handle headers and cookies
+            $this->resp_headers = $this->_parseHeaders($r_headers);
+            if(isset($this->resp_headers['set-cookie'])){
+                foreach ((array) $this->resp_headers['set-cookie'] as $cookie){
+                    list($cookie)   = explode(';',$cookie,2);
+                    list($key,$val) = explode('=',$cookie,2);
+                    $key = trim($key);
+                    if($val == 'deleted'){
+                        if(isset($this->cookies[$key])){
+                            unset($this->cookies[$key]);
+                        }
+                    }elseif($key){
+                        $this->cookies[$key] = $val;
                     }
                 }
-                // perform redirected request, always via GET (required by RFC)
-                return $this->sendRequest($this->resp_headers['location'],array(),'GET');
             }
-        }
 
-        // check if headers are as expected
-        if($this->header_regexp && !preg_match($this->header_regexp,$r_headers)){
-            $this->error = 'The received headers did not match the given regexp';
-            unset($this->connections[$connectionId]);
-            return false;
-        }
+            $this->_debug('Object headers',$this->resp_headers);
 
-        //read body (with chunked encoding if needed)
-        $r_body    = '';
-        if(preg_match('/transfer\-(en)?coding:\s*chunked\r\n/i',$r_headers)){
-            do {
-                unset($chunk_size);
+            // check server status code to follow redirect
+            if($this->status == 301 || $this->status == 302 ){
+                if (empty($this->resp_headers['location'])){
+                    throw new HTTPClientException('Redirect but no Location Header found');
+                }elseif($this->redirect_count == $this->max_redirect){
+                    throw new HTTPClientException('Maximum number of redirects exceeded');
+                }else{
+                    // close the connection because we don't handle content retrieval here
+                    // that's the easiest way to clean up the connection
+                    fclose($socket);
+                    unset(self::$connections[$connectionId]);
+
+                    $this->redirect_count++;
+                    $this->referer = $url;
+                    // handle non-RFC-compliant relative redirects
+                    if (!preg_match('/^http/i', $this->resp_headers['location'])){
+                        if($this->resp_headers['location'][0] != '/'){
+                            $this->resp_headers['location'] = $uri['scheme'].'://'.$uri['host'].':'.$uri['port'].
+                                                            dirname($uri['path']).'/'.$this->resp_headers['location'];
+                        }else{
+                            $this->resp_headers['location'] = $uri['scheme'].'://'.$uri['host'].':'.$uri['port'].
+                                                            $this->resp_headers['location'];
+                        }
+                    }
+                    // perform redirected request, always via GET (required by RFC)
+                    return $this->sendRequest($this->resp_headers['location'],array(),'GET');
+                }
+            }
+
+            // check if headers are as expected
+            if($this->header_regexp && !preg_match($this->header_regexp,$r_headers))
+                throw new HTTPClientException('The received headers did not match the given regexp');
+
+            //read body (with chunked encoding if needed)
+            $r_body    = '';
+            if((isset($this->resp_headers['transfer-encoding']) && $this->resp_headers['transfer-encoding'] == 'chunked')
+            || (isset($this->resp_headers['transfer-coding']) && $this->resp_headers['transfer-coding'] == 'chunked')){
+                $abort = false;
                 do {
-                    if(feof($socket)){
-                        $this->error = 'Premature End of File (socket)';
-                        unset($this->connections[$connectionId]);
-                        return false;
+                    $chunk_size = '';
+                    while (preg_match('/^[a-zA-Z0-9]?$/',$byte=$this->_readData($socket,1,'chunk'))){
+                        // read chunksize until \r
+                        $chunk_size .= $byte;
+                        if (strlen($chunk_size) > 128) // set an abritrary limit on the size of chunks
+                            throw new HTTPClientException('Allowed response size exceeded');
                     }
-                    if(time()-$start > $this->timeout){
-                        $this->status = -100;
-                        $this->error = sprintf('Timeout while reading chunk (%.3fs)',$this->_time() - $this->start);
-                        unset($this->connections[$connectionId]);
-                        return false;
-                    }
-                    $byte = fread($socket,1);
-                    $chunk_size .= $byte;
-                } while (preg_match('/[a-zA-Z0-9]/',$byte)); // read chunksize including \r
+                    $this->_readLine($socket, 'chunk');     // readtrailing \n
+                    $chunk_size = hexdec($chunk_size);
 
-                $byte = fread($socket,1);     // readtrailing \n
-                $chunk_size = hexdec($chunk_size);
-                if ($chunk_size) {
-                    $this_chunk = fread($socket,$chunk_size);
-                    $r_body    .= $this_chunk;
-                    $byte = fread($socket,2); // read trailing \r\n
+                    if($this->max_bodysize && $chunk_size+strlen($r_body) > $this->max_bodysize){
+                        if ($this->max_bodysize_abort)
+                            throw new HTTPClientException('Allowed response size exceeded');
+                        $this->error = 'Allowed response size exceeded';
+                        $chunk_size = $this->max_bodysize - strlen($r_body);
+                        $abort = true;
+                    }
+
+                    if ($chunk_size > 0) {
+                        $r_body .= $this->_readData($socket, $chunk_size, 'chunk');
+                        $byte = $this->_readData($socket, 2, 'chunk'); // read trailing \r\n
+                    }
+                } while ($chunk_size && !$abort);
+            }elseif(isset($this->resp_headers['content-length']) && !isset($this->resp_headers['transfer-encoding'])){
+                /* RFC 2616
+                 * If a message is received with both a Transfer-Encoding header field and a Content-Length
+                 * header field, the latter MUST be ignored.
+                 */
+
+                // read up to the content-length or max_bodysize
+                // for keep alive we need to read the whole message to clean up the socket for the next read
+                if(!$this->keep_alive && $this->max_bodysize && $this->max_bodysize < $this->resp_headers['content-length']){
+                    $length = $this->max_bodysize;
+                }else{
+                    $length = $this->resp_headers['content-length'];
                 }
 
-                if($this->max_bodysize && strlen($r_body) > $this->max_bodysize){
-                    $this->error = 'Allowed response size exceeded';
-                    if ($this->max_bodysize_abort){
-                        unset($this->connections[$connectionId]);
-                        return false;
-                    } else {
-                        break;
-                    }
-                }
-            } while ($chunk_size);
-        }else{
-            // read entire socket
-            while (!feof($socket)) {
-                if(time()-$start > $this->timeout){
-                    $this->status = -100;
-                    $this->error = sprintf('Timeout while reading response (%.3fs)',$this->_time() - $this->start);
-                    unset($this->connections[$connectionId]);
-                    return false;
-                }
-                $r_body .= fread($socket,4096);
-                $r_size = strlen($r_body);
-                if($this->max_bodysize && $r_size > $this->max_bodysize){
-                    $this->error = 'Allowed response size exceeded';
-                    if ($this->max_bodysize_abort) {
-                        unset($this->connections[$connectionId]);
-                        return false;
-                    } else {
-                        break;
-                    }
-                }
-                if(isset($this->resp_headers['content-length']) &&
-                   !isset($this->resp_headers['transfer-encoding']) &&
-                   $this->resp_headers['content-length'] == $r_size){
-                    // we read the content-length, finish here
-                    break;
+                $r_body = $this->_readData($socket, $length, 'response (content-length limited)', true);
+            }else{
+                // read entire socket
+                $r_size = 0;
+                while (!feof($socket)) {
+                    $r_body .= $this->_readData($socket, 4096, 'response (unlimited)', true);
                 }
             }
+
+            // recheck body size, we might had to read the whole body, so we abort late or trim here
+            if($this->max_bodysize){
+                if(strlen($r_body) > $this->max_bodysize){
+                    if ($this->max_bodysize_abort) {
+                        throw new HTTPClientException('Allowed response size exceeded');
+                    } else {
+                        $this->error = 'Allowed response size exceeded';
+                    }
+                }
+            }
+
+        } catch (HTTPClientException $err) {
+            $this->error = $err->getMessage();
+            if ($err->getCode())
+                $this->status = $err->getCode();
+            unset(self::$connections[$connectionId]);
+            fclose($socket);
+            return false;
         }
 
         if (!$this->keep_alive ||
@@ -525,7 +496,7 @@ class HTTPClient {
             // close socket
             $status = socket_get_status($socket);
             fclose($socket);
-            unset($this->connections[$connectionId]);
+            unset(self::$connections[$connectionId]);
         }
 
         // decode gzip if needed
@@ -546,13 +517,200 @@ class HTTPClient {
         return true;
     }
 
+    /**
+     * Tries to establish a CONNECT tunnel via Proxy
+     *
+     * Protocol, Servername and Port will be stripped from the request URL when a successful CONNECT happened
+     *
+     * @param resource &$socket
+     * @param string   &$requesturl
+     * @return bool true if a tunnel was established
+     */
+    function _ssltunnel(&$socket, &$requesturl){
+        if(!$this->proxy_host) return false;
+        $requestinfo = parse_url($requesturl);
+        if($requestinfo['scheme'] != 'https') return false;
+        if(!$requestinfo['port']) $requestinfo['port'] = 443;
+
+        // build request
+        $request  = "CONNECT {$requestinfo['host']}:{$requestinfo['port']} HTTP/1.0".HTTP_NL;
+        $request .= "Host: {$requestinfo['host']}".HTTP_NL;
+        if($this->proxy_user) {
+                'Proxy-Authorization Basic '.base64_encode($this->proxy_user.':'.$this->proxy_pass).HTTP_NL;
+        }
+        $request .= HTTP_NL;
+
+        $this->_debug('SSL Tunnel CONNECT',$request);
+        $this->_sendData($socket, $request, 'SSL Tunnel CONNECT');
+
+        // read headers from socket
+        $r_headers = '';
+        do{
+            $r_line = $this->_readLine($socket, 'headers');
+            $r_headers .= $r_line;
+        }while($r_line != "\r\n" && $r_line != "\n");
+
+        $this->_debug('SSL Tunnel Response',$r_headers);
+        if(preg_match('/^HTTP\/1\.0 200/i',$r_headers)){
+            if (stream_socket_enable_crypto($socket, true, STREAM_CRYPTO_METHOD_SSLv3_CLIENT)) {
+                $requesturl = $requestinfo['path'];
+                return true;
+            }
+        }
+        return false;
+    }
+
+    /**
+     * Safely write data to a socket
+     *
+     * @param  resource $socket     An open socket handle
+     * @param  string   $data       The data to write
+     * @param  string   $message    Description of what is being read
+     * @throws HTTPClientException
+     * @author Tom N Harris <tnharris@whoopdedo.org>
+     */
+    function _sendData($socket, $data, $message) {
+        // send request
+        $towrite = strlen($data);
+        $written = 0;
+        while($written < $towrite){
+            // check timeout
+            $time_used = $this->_time() - $this->start;
+            if($time_used > $this->timeout)
+                throw new HTTPClientException(sprintf('Timeout while sending %s (%.3fs)',$message, $time_used), -100);
+            if(feof($socket))
+                throw new HTTPClientException("Socket disconnected while writing $message");
+
+            // select parameters
+            $sel_r = null;
+            $sel_w = array($socket);
+            $sel_e = null;
+            // wait for stream ready or timeout (1sec)
+            if(@stream_select($sel_r,$sel_w,$sel_e,1) === false){
+                 usleep(1000);
+                 continue;
+            }
+
+            // write to stream
+            $nbytes = fwrite($socket, substr($data,$written,4096));
+            if($nbytes === false)
+                throw new HTTPClientException("Failed writing to socket while sending $message", -100);
+            $written += $nbytes;
+        }
+    }
+
+    /**
+     * Safely read data from a socket
+     *
+     * Reads up to a given number of bytes or throws an exception if the
+     * response times out or ends prematurely.
+     *
+     * @param  resource $socket     An open socket handle in non-blocking mode
+     * @param  int      $nbytes     Number of bytes to read
+     * @param  string   $message    Description of what is being read
+     * @param  bool     $ignore_eof End-of-file is not an error if this is set
+     * @throws HTTPClientException
+     * @return string
+     * @author Tom N Harris <tnharris@whoopdedo.org>
+     */
+    function _readData($socket, $nbytes, $message, $ignore_eof = false) {
+        $r_data = '';
+        // Does not return immediately so timeout and eof can be checked
+        if ($nbytes < 0) $nbytes = 0;
+        $to_read = $nbytes;
+        do {
+            $time_used = $this->_time() - $this->start;
+            if ($time_used > $this->timeout)
+                throw new HTTPClientException(
+                        sprintf('Timeout while reading %s after %d bytes (%.3fs)', $message,
+                                strlen($r_data), $time_used), -100);
+            if(feof($socket)) {
+                if(!$ignore_eof)
+                    throw new HTTPClientException("Premature End of File (socket) while reading $message");
+                break;
+            }
+
+            if ($to_read > 0) {
+                // select parameters
+                $sel_r = array($socket);
+                $sel_w = null;
+                $sel_e = null;
+                // wait for stream ready or timeout (1sec)
+                if(@stream_select($sel_r,$sel_w,$sel_e,1) === false){
+                     usleep(1000);
+                     continue;
+                }
+
+                $bytes = fread($socket, $to_read);
+                if($bytes === false)
+                    throw new HTTPClientException("Failed reading from socket while reading $message", -100);
+                $r_data .= $bytes;
+                $to_read -= strlen($bytes);
+            }
+        } while ($to_read > 0 && strlen($r_data) < $nbytes);
+        return $r_data;
+    }
+
+    /**
+     * Safely read a \n-terminated line from a socket
+     *
+     * Always returns a complete line, including the terminating \n.
+     *
+     * @param  resource $socket     An open socket handle in non-blocking mode
+     * @param  string   $message    Description of what is being read
+     * @throws HTTPClientException
+     * @return string
+     * @author Tom N Harris <tnharris@whoopdedo.org>
+     */
+    function _readLine($socket, $message) {
+        $r_data = '';
+        do {
+            $time_used = $this->_time() - $this->start;
+            if ($time_used > $this->timeout)
+                throw new HTTPClientException(
+                        sprintf('Timeout while reading %s (%.3fs) >%s<', $message, $time_used, $r_data),
+                        -100);
+            if(feof($socket))
+                throw new HTTPClientException("Premature End of File (socket) while reading $message");
+
+            // select parameters
+            $sel_r = array($socket);
+            $sel_w = null;
+            $sel_e = null;
+            // wait for stream ready or timeout (1sec)
+            if(@stream_select($sel_r,$sel_w,$sel_e,1) === false){
+                 usleep(1000);
+                 continue;
+            }
+
+            $r_data = fgets($socket, 1024);
+        } while (!preg_match('/\n$/',$r_data));
+        return $r_data;
+    }
+
     /**
      * print debug info
      *
+     * Uses _debug_text or _debug_html depending on the SAPI name
+     *
      * @author Andreas Gohr <andi@splitbrain.org>
      */
     function _debug($info,$var=null){
         if(!$this->debug) return;
+        if(php_sapi_name() == 'cli'){
+            $this->_debug_text($info, $var);
+        }else{
+            $this->_debug_html($info, $var);
+        }
+    }
+
+    /**
+     * print debug info as HTML
+     *
+     * @param      $info
+     * @param null $var
+     */
+    function _debug_html($info, $var=null){
         print '<b>'.$info.'</b> '.($this->_time() - $this->start).'s<br />';
         if(!is_null($var)){
             ob_start();
@@ -563,10 +721,22 @@ class HTTPClient {
         }
     }
 
+    /**
+     * prints debug info as plain text
+     *
+     * @param      $info
+     * @param null $var
+     */
+    function _debug_text($info, $var=null){
+        print '*'.$info.'* '.($this->_time() - $this->start)."s\n";
+        if(!is_null($var)) print_r($var);
+        print "\n-----------------------------------------------\n";
+    }
+
     /**
      * Return current timestamp in microsecond resolution
      */
-    function _time(){
+    static function _time(){
         list($usec, $sec) = explode(" ", microtime());
         return ((float)$usec + (float)$sec);
     }
@@ -580,13 +750,14 @@ class HTTPClient {
      */
     function _parseHeaders($string){
         $headers = array();
-        if (!preg_match_all('/^\s*([\w-]+)\s*:\s*([\S \t]+)\s*$/m', $string,
-                            $matches, PREG_SET_ORDER)) {
-            return $headers;
-        }
-        foreach($matches as $match){
-            list(, $key, $val) = $match;
+        $lines = explode("\n",$string);
+        array_shift($lines); //skip first line (status)
+        foreach($lines as $line){
+            @list($key, $val) = explode(':',$line,2);
+            $key = trim($key);
+            $val = trim($val);
             $key = strtolower($key);
+            if(!$key) continue;
             if(isset($headers[$key])){
                 if(is_array($headers[$key])){
                     $headers[$key][] = $val;
@@ -625,7 +796,7 @@ class HTTPClient {
             $headers .= "$key=$val; ";
         }
         $headers = substr($headers, 0, -2);
-        if ($headers !== '') $headers = "Cookie: $headers".HTTP_NL;
+        if ($headers) $headers = "Cookie: $headers".HTTP_NL;
         return $headers;
     }
 
@@ -676,6 +847,8 @@ class HTTPClient {
     /**
      * Generates a unique identifier for a connection.
      *
+     * @param  string $server
+     * @param  string $port
      * @return string unique identifier
      */
     function _uniqueConnectionId($server, $port) {
