@@ -5,6 +5,7 @@
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  * @author Carles Bellver <carles.bellver@cent.uji.es>
  * @author Carles Bellver <carles.bellver@gmail.com>
+ * @author daniel@6temes.cat
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -27,7 +28,7 @@ $lang['btn_revs']              = 'Revisions anteriors';
 $lang['btn_recent']            = 'Canvis recents';
 $lang['btn_upload']            = 'Penja';
 $lang['btn_cancel']            = 'Cancel·la';
-$lang['btn_index']             = 'Índex';
+$lang['btn_index']             = 'Mapa del lloc';
 $lang['btn_secedit']           = 'Edita';
 $lang['btn_login']             = 'Entra';
 $lang['btn_logout']            = 'Surt';
@@ -38,17 +39,15 @@ $lang['btn_back']              = 'Enrere';
 $lang['btn_backlink']          = 'Què hi enllaça';
 $lang['btn_backtomedia']       = 'Torna a la selecció de fitxers';
 $lang['btn_subscribe']         = 'Subscripció a canvis d\'aquesta pàgina';
-$lang['btn_unsubscribe']       = 'Cancel·la subscripció a pàgina';
-$lang['btn_subscribens']       = 'Subscripció a canvis d\'aquest espai';
-$lang['btn_unsubscribens']     = 'Cancel·la subscripció a espai';
 $lang['btn_profile']           = 'Actualització del perfil';
 $lang['btn_reset']             = 'Reinicia';
-$lang['btn_resendpwd']         = 'Envia nova contrasenya';
+$lang['btn_resendpwd']         = 'Estableix una nova contrasenya';
 $lang['btn_draft']             = 'Edita esborrany';
 $lang['btn_recover']           = 'Recupera esborrany';
 $lang['btn_draftdel']          = 'Suprimeix esborrany';
 $lang['btn_revert']            = 'Restaura';
 $lang['btn_register']          = 'Registra\'m';
+$lang['btn_apply']             = 'Aplica';
 $lang['loggedinas']            = 'Heu entrat com';
 $lang['user']                  = 'Nom d\'usuari';
 $lang['pass']                  = 'Contrasenya';
@@ -78,7 +77,7 @@ $lang['profnoempty']           = 'No es pot deixar en blanc el nom o l\'adreça
 $lang['profchanged']           = 'El perfil d\'usuari s\'ha actualitzat correctament.';
 $lang['pwdforget']             = 'Heu oblidat la contrasenya? Podeu obtenir-ne una de nova.';
 $lang['resendna']              = 'Aquest wiki no permet tornar a enviar la contrasenya.';
-$lang['resendpwd']             = 'Enviament d\'una nova contrasenya per a';
+$lang['resendpwd']             = 'Estableix una nova contrasenya per';
 $lang['resendpwdmissing']      = 'Heu d\'emplenar tots els camps.';
 $lang['resendpwdnouser']       = 'No s\'ha pogut trobar aquest usuari a la base de dades.';
 $lang['resendpwdbadauth']      = 'Aquest codi d\'autenticació no és vàlid. Assegureu-vos d\'utilitzar l\'enllaç de confirmació complet.';
@@ -91,10 +90,52 @@ $lang['searchmedia_in']        = 'Cerca en: %s';
 $lang['txt_upload']            = 'Trieu el fitxer que voleu penjar';
 $lang['txt_filename']          = 'Introduïu el nom wiki (opcional)';
 $lang['txt_overwrt']           = 'Sobreescriu el fitxer actual';
+$lang['maxuploadsize']         = 'Puja com a màxim %s per arxiu.';
 $lang['lockedby']              = 'Actualment blocat per:';
 $lang['lockexpire']            = 'Venciment del blocatge:';
-$lang['willexpire']            = 'El blocatge per a editar aquesta pàgina venç d\'aquí a un minut.\nUtilitzeu la visualització prèvia per reiniciar el rellotge i evitar conflictes.';
-$lang['js']['notsavedyet']     = "Heu fet canvis que es perdran si no els deseu.\nVoleu continuar?";
+$lang['js']['willexpire']      = 'El blocatge per a editar aquesta pàgina venç d\'aquí a un minut.\nUtilitzeu la visualització prèvia per reiniciar el rellotge i evitar conflictes.';
+$lang['js']['notsavedyet']     = 'Heu fet canvis que es perdran si no els deseu.
+Voleu continuar?';
+$lang['js']['searchmedia']     = 'Cerca fitxers';
+$lang['js']['keepopen']        = 'Manté la finestra oberta';
+$lang['js']['hidedetails']     = 'Oculta detalls';
+$lang['js']['mediatitle']      = 'Propietats de l\'enllaç';
+$lang['js']['mediadisplay']    = 'Tipus d\'enllaç';
+$lang['js']['mediaalign']      = 'Alineació';
+$lang['js']['mediasize']       = 'Mida de la imatge';
+$lang['js']['mediatarget']     = 'Destí de l\'enllaç';
+$lang['js']['mediaclose']      = 'Tanca';
+$lang['js']['mediainsert']     = 'Inserta';
+$lang['js']['mediadisplayimg'] = 'Mostra la imatge';
+$lang['js']['mediadisplaylnk'] = 'Mostra només l\'enllaç';
+$lang['js']['mediasmall']      = 'Versió petita';
+$lang['js']['mediamedium']     = 'Versió mitjana';
+$lang['js']['medialarge']      = 'Versió gran';
+$lang['js']['mediaoriginal']   = 'Versió original';
+$lang['js']['medialnk']        = 'Enllaç a la pàgina de detalls';
+$lang['js']['mediadirect']     = 'Enllaç directe a l\'original';
+$lang['js']['medianolnk']      = 'No hi ha enllaç';
+$lang['js']['medianolink']     = 'No enllacis la imatge';
+$lang['js']['medialeft']       = 'Alinea la imatge a l\'esquerra.';
+$lang['js']['mediaright']      = 'Alinea la imatge a la dreta.';
+$lang['js']['mediacenter']     = 'Alinea la imatge al mig.';
+$lang['js']['medianoalign']    = 'No facis servir alineació.';
+$lang['js']['nosmblinks']      = 'Els enllaços amb recursos compartits de Windows només funcionen amb el Microsoft Internet Explorer.
+Si voleu podeu copiar i enganxar l\'enllaç.';
+$lang['js']['linkwiz']         = 'Auxiliar d\'enllaços';
+$lang['js']['linkto']          = 'Enllaça a:';
+$lang['js']['del_confirm']     = 'Suprimiu aquesta entrada?';
+$lang['js']['restore_confirm'] = 'Vols realment restaurar aquesta versió?';
+$lang['js']['media_diff']      = 'Veure les diferències:';
+$lang['js']['media_diff_both'] = 'Un al costat de l\'altre';
+$lang['js']['media_diff_opacity'] = 'Resalta';
+$lang['js']['media_diff_portions'] = 'Llisca';
+$lang['js']['media_select']    = 'Escull els arxius';
+$lang['js']['media_upload_btn'] = 'Pujar';
+$lang['js']['media_done_btn']  = 'Fet';
+$lang['js']['media_drop']      = 'Arrossega aquí els arxius a pujar';
+$lang['js']['media_cancel']    = 'esborra';
+$lang['js']['media_overwrt']   = 'Sobreescriu els arxius existents';
 $lang['rssfailed']             = 'S\'ha produït un error en recollir aquesta alimentació: ';
 $lang['nothingfound']          = 'No s\'ha trobat res.';
 $lang['mediaselect']           = 'Selecció de fitxers';
@@ -112,15 +153,7 @@ $lang['deletefail']            = 'No s\'ha pogut suprimir el fitxer "%s". Compro
 $lang['mediainuse']            = 'No s\'ha pogut suprimir el fitxer "%s". Encara s\'està utilitzant.';
 $lang['namespaces']            = 'Espais';
 $lang['mediafiles']            = 'Fitxers disponibles en';
-$lang['js']['searchmedia']     = 'Cerca fitxers';
-$lang['js']['keepopen']        = 'Manté la finestra oberta';
-$lang['js']['hidedetails']     = 'Oculta detalls';
-$lang['js']['nosmblinks']      = 'Els enllaços amb recursos compartits de Windows només funcionen amb el Microsoft Internet Explorer.
-Si voleu podeu copiar i enganxar l\'enllaç.';
-$lang['js']['linkwiz']         = 'Auxiliar d\'enllaços';
-$lang['js']['linkto']          = 'Enllaça a:';
-$lang['js']['del_confirm']     = 'Suprimiu aquesta entrada?';
-$lang['js']['mu_btn']          = 'Penja múltiples fitxers';
+$lang['accessdenied']          = 'No teniu permís per a veure aquesta pàgina.';
 $lang['mediausage']            = 'Utilitzeu la sintaxi següent per referir-vos a aquest enllaç:';
 $lang['mediaview']             = 'Mostra el fitxer original';
 $lang['mediaroot']             = 'arrel';
@@ -136,6 +169,10 @@ $lang['current']               = 'actual';
 $lang['yours']                 = 'La vostra versió';
 $lang['diff']                  = 'Mostra diferències amb la versió actual';
 $lang['diff2']                 = 'Mostra diferències entre les revisions seleccionades';
+$lang['difflink']              = 'Enllaç a la visualització de la comparació';
+$lang['diff_type']             = 'Veieu les diferències:';
+$lang['diff_inline']           = 'En línia';
+$lang['diff_side']             = 'Un al costat de l\'altre';
 $lang['line']                  = 'Línia';
 $lang['breadcrumb']            = 'Camí';
 $lang['youarehere']            = 'Sou aquí';
@@ -143,15 +180,25 @@ $lang['lastmod']               = 'Darrera modificació';
 $lang['by']                    = 'per';
 $lang['deleted']               = 'suprimit';
 $lang['created']               = 'creat';
-$lang['restored']              = 's\'ha restaurat una versió anterior';
+$lang['restored']              = 's\'ha restaurat una versió anterior %s';
 $lang['external_edit']         = 'edició externa';
 $lang['summary']               = 'Resum d\'edició';
 $lang['noflash']               = 'Per a visualitzar aquest contingut necessiteu el <a href="http://www.adobe.com/products/flashplayer/">connector d\'Adobe Flash</a>.';
 $lang['download']              = 'Baixa el fragment';
+$lang['tools']                 = 'Eines';
+$lang['user_tools']            = 'Eines de l\'usuari';
+$lang['site_tools']            = 'Eines del lloc';
+$lang['page_tools']            = 'Eines de la pàgina';
+$lang['skip_to_content']       = 'salta al contingut';
+$lang['sidebar']               = 'Barra lateral';
 $lang['mail_newpage']          = 'pàgina afegida:';
 $lang['mail_changed']          = 'pàgina modificada:';
 $lang['mail_new_user']         = 'nou usuari:';
 $lang['mail_upload']           = 'fitxer penjat:';
+$lang['changes_type']          = 'Veure els canvis de';
+$lang['pages_changes']         = 'Pàgines';
+$lang['media_changes']         = 'Arxius gràfics';
+$lang['both_changes']          = 'Pàgines i arxius gràfics';
 $lang['qb_bold']               = 'Negreta';
 $lang['qb_italic']             = 'Cursiva';
 $lang['qb_underl']             = 'Subratllat';
@@ -192,13 +239,27 @@ $lang['img_copyr']             = 'Copyright';
 $lang['img_format']            = 'Format';
 $lang['img_camera']            = 'Càmera';
 $lang['img_keywords']          = 'Paraules clau';
-$lang['subscribe_success']     = 'S\'ha afegit %s a la llista de subscripcions de %s';
-$lang['subscribe_error']       = 'S\'ha produït un error en afegir %s a la llista de subscripcions de %s';
-$lang['subscribe_noaddress']   = 'No hi ha cap adreça de correu associada al vostre nom d\'usuari. No se us ha pogut afegir a la llista de subscripcions.';
-$lang['unsubscribe_success']   = '%s ha estat suprimit de la llista de subscripcions de %s';
-$lang['unsubscribe_error']     = 'S\'ha produït un error en suprimir %s de la llista de subscripcions de %s';
+$lang['img_width']             = 'Ample';
+$lang['img_height']            = 'Alçada';
+$lang['subscr_subscribe_success'] = 'S\'ha afegit %s a la llista de subscripcions per %s';
+$lang['subscr_subscribe_error'] = 'Hi ha hagut un error a l\'afegir %s a la llista per %s';
+$lang['subscr_subscribe_noaddress'] = 'No hi ha cap adreça associada pel vostre nom d\'usuari, no podeu ser afegit a la llista de subscripcions';
+$lang['subscr_unsubscribe_success'] = 'S\'ha esborrat %s de la llista de subscripcions per %s';
+$lang['subscr_unsubscribe_error'] = 'Hi ha hagut un error a l\'esborrar %s de la llista de subscripcions per %s';
+$lang['subscr_already_subscribed'] = '%s ja està subscrit a %s';
+$lang['subscr_not_subscribed'] = '%s no està subscrit a %s';
+$lang['subscr_m_not_subscribed'] = 'En aquests moments no esteu subscrit a l\'actual pàgina o espai';
+$lang['subscr_m_new_header']   = 'Afegeix subcripció';
+$lang['subscr_m_current_header'] = 'Subscripcions actuals';
+$lang['subscr_m_unsubscribe']  = 'Donar-se de baixa';
+$lang['subscr_m_subscribe']    = 'Donar-se d\'alta';
+$lang['subscr_m_receive']      = 'Rebre';
+$lang['subscr_style_every']    = 'Envia\'m un correu electrònic per a cada canvi';
+$lang['subscr_style_digest']   = 'Envia\'m un correu electrònic amb un resum dels canvis per a cada pàgina (cada %.2f dies)';
+$lang['subscr_style_list']     = 'llistat de pàgines canviades des de l\'últim correu electrònic  (cada %.2f dies)';
 $lang['authmodfailed']         = 'La configuració de l\'autenticació d\'usuaris és errònia. Informeu els administradors del wiki.';
 $lang['authtempfail']          = 'L\'autenticació d\'usuaris no està disponible temporalment. Si aquesta situació persisteix, si us plau informeu els administradors del wiki.';
+$lang['authpwdexpire']         = 'La vostra contrasenya caducarà en %d dies, l\'hauríeu de canviar aviat.';
 $lang['i_chooselang']          = 'Trieu l\'idioma';
 $lang['i_installer']           = 'Instal·lador de DokuWiki';
 $lang['i_wikiname']            = 'Nom del wiki';
@@ -220,21 +281,7 @@ $lang['i_pol0']                = 'Wiki obert (tothom pot llegir, escriure i penj
 $lang['i_pol1']                = 'Wiki públic (tothom pot llegir, els usuaris registrats poden escriure i penjar fitxers)';
 $lang['i_pol2']                = 'Wiki tancat (només els usuaris registrats poden llegir, escriure i penjar fitxers)';
 $lang['i_retry']               = 'Reintenta';
-$lang['mu_intro']              = 'Aquí podeu penjar múltiples fitxers d\'una vegada. Feu clic en el botó Explora per afegir els fitxers a la cua. Després, premeu Penja.';
-$lang['mu_gridname']           = 'Nom del fitxer';
-$lang['mu_gridsize']           = 'Mida';
-$lang['mu_gridstat']           = 'Estat';
-$lang['mu_namespace']          = 'Espai';
-$lang['mu_browse']             = 'Explora';
-$lang['mu_toobig']             = 'massa gran';
-$lang['mu_ready']              = 'llest per a penjar';
-$lang['mu_done']               = 'complet';
-$lang['mu_fail']               = 'error';
-$lang['mu_authfail']           = 'la sessió ha vençut';
-$lang['mu_progress']           = 'càrrega @PCT@%';
-$lang['mu_filetypes']          = 'Tipus de fitxer permesos';
-$lang['mu_info']               = 'fitxers penjats.';
-$lang['mu_lasterr']            = 'Darrer error:';
+$lang['i_license']             = 'Escolliu el tipus de llicència que voleu fer servir per al vostre contingut:';
 $lang['recent_global']         = 'Esteu veient els canvis recents de l\'espai <strong>%s</strong>. També podeu veure els <a href="%s">canvis recents de tot el wiki</a>.';
 $lang['years']                 = 'fa %d anys';
 $lang['months']                = 'fa %d mesos';
@@ -243,3 +290,27 @@ $lang['days']                  = 'fa %d dies';
 $lang['hours']                 = 'fa %d hores';
 $lang['minutes']               = 'fa %d minuts';
 $lang['seconds']               = 'fa %d segons';
+$lang['wordblock']             = 'El vostre canvi no s\'ha guardat perquè conté text blocat (spam)';
+$lang['media_uploadtab']       = 'Puja';
+$lang['media_searchtab']       = 'Busca';
+$lang['media_file']            = 'Fitxer';
+$lang['media_viewtab']         = 'Mostra';
+$lang['media_edittab']         = 'Edita';
+$lang['media_historytab']      = 'Històric';
+$lang['media_list_thumbs']     = 'Miniatura';
+$lang['media_list_rows']       = 'Files';
+$lang['media_sort_name']       = 'Nom';
+$lang['media_sort_date']       = 'Data';
+$lang['media_namespaces']      = 'Escolliu l\'espai';
+$lang['media_files']           = 'Arxius a %s';
+$lang['media_upload']          = 'Puja a %s';
+$lang['media_search']          = 'Busca a %s';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s a %s';
+$lang['media_edit']            = 'Edita %s';
+$lang['media_history']         = 'Històric de %s';
+$lang['media_meta_edited']     = 'metadata editada';
+$lang['media_perm_read']       = 'No teniu permisos suficients per a llegir arxius.';
+$lang['media_perm_upload']     = 'No teniu permisos suficients per a pujar arxius';
+$lang['media_update']          = 'Puja la nova versió';
+$lang['media_restore']         = 'Restaura aquesta versió';
