@@ -5,6 +5,7 @@
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  * @author Xabi Ezpeleta <xezpeleta@mendikute.com>
  * @author Inko Illarramendi <inko.i.a@gmail.com>
+ * @author Zigor Astarbe <astarbe@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -40,12 +41,14 @@ $lang['btn_backtomedia']       = 'Atzera Multimedia Fitxategiaren Aukeraketara';
 $lang['btn_subscribe']         = 'Harpidetu Orri Aldaketetara';
 $lang['btn_profile']           = 'Eguneratu Profila ';
 $lang['btn_reset']             = 'Aldaketak Desegin';
-$lang['btn_resendpwd']         = 'Pasahitz berria bidali';
+$lang['btn_resendpwd']         = 'Pasahitza berria ezarri';
 $lang['btn_draft']             = 'Editatu zirriborroa';
 $lang['btn_recover']           = 'Berreskuratu zirriborroa';
 $lang['btn_draftdel']          = 'Ezabatu zirriborroa';
 $lang['btn_revert']            = 'Berrezarri';
 $lang['btn_register']          = 'Erregistratu';
+$lang['btn_apply']             = 'Baieztatu';
+$lang['btn_media']             = 'Media Kudeatzailea';
 $lang['loggedinas']            = 'Erabiltzailea';
 $lang['user']                  = 'Erabiltzailea';
 $lang['pass']                  = 'Pasahitza';
@@ -75,7 +78,7 @@ $lang['profnoempty']           = 'Izen edota e-posta hutsa ez dago onartua.';
 $lang['profchanged']           = 'Erabiltzaile profila arrakastaz eguneratua.';
 $lang['pwdforget']             = 'Pasahitza ahaztu duzu? Eskuratu berri bat';
 $lang['resendna']              = 'Wiki honek ez du pasahitz berbidalketa onartzen.';
-$lang['resendpwd']             = 'Bidali pasahitz berria honentzat:';
+$lang['resendpwd']             = '-entzat pasahitza berria ezarri';
 $lang['resendpwdmissing']      = 'Barkatu, eremu guztiak bete behar dituzu.';
 $lang['resendpwdnouser']       = 'Barkatu, ez dugu erabiltzaile hori datu-basean aurkitzen';
 $lang['resendpwdbadauth']      = 'Barkatu, kautotze kodea ez da baliozkoa. Ziurtatu baieztapen esteka osoa erabili duzula.';
@@ -90,7 +93,7 @@ $lang['txt_filename']          = 'Idatzi wikiname-a (aukerazkoa)';
 $lang['txt_overwrt']           = 'Oraingo fitxategiaren gainean idatzi';
 $lang['lockedby']              = 'Momentu honetan blokeatzen:';
 $lang['lockexpire']            = 'Blokeaketa iraungitzen da:';
-$lang['willexpire']            = 'Zure blokeaketa orri hau aldatzeko minutu batean iraungitzen da.\nGatazkak saihesteko, aurreikusi botoia erabili blokeaketa denboragailua berrabiarazteko.';
+$lang['js']['willexpire']      = 'Zure blokeaketa orri hau aldatzeko minutu batean iraungitzen da.\nGatazkak saihesteko, aurreikusi botoia erabili blokeaketa denboragailua berrabiarazteko.';
 $lang['js']['notsavedyet']     = 'Gorde gabeko aldaketak galdu egingo dira.
 Benetan jarraitu nahi duzu?';
 $lang['js']['searchmedia']     = 'Bilatu fitxategiak';
@@ -122,7 +125,15 @@ Esteka kopiatu eta itsatsi dezakezu dena den.';
 $lang['js']['linkwiz']         = 'Estekatze Laguntzailea';
 $lang['js']['linkto']          = 'Estekatu hona:';
 $lang['js']['del_confirm']     = 'Benetan ezabatu aukeratutako fitxategia(k)?';
-$lang['js']['mu_btn']          = 'Igo hainbat fitxategi aldi berean';
+$lang['js']['restore_confirm'] = 'Benetan bertsio hau berrezarri?';
+$lang['js']['media_diff']      = 'Diferentziak ikusi:';
+$lang['js']['media_diff_both'] = 'Ondoz ondo';
+$lang['js']['media_select']    = 'Fitxategiak hautatu';
+$lang['js']['media_upload_btn'] = 'Igo';
+$lang['js']['media_done_btn']  = 'Egina';
+$lang['js']['media_drop']      = 'Fitxategiak igotzeko hona bota';
+$lang['js']['media_cancel']    = 'ezabatu';
+$lang['js']['media_overwrt']   = 'Dauden fitxategiak berridatzi';
 $lang['rssfailed']             = 'Errorea gertatu da feed hau irakurtzean:';
 $lang['nothingfound']          = 'Ez da ezer aurkitu.';
 $lang['mediaselect']           = 'Aukeratu Multimedia fitxategia';
@@ -167,16 +178,26 @@ $lang['lastmod']               = 'Azken aldaketa';
 $lang['by']                    = 'egilea:';
 $lang['deleted']               = 'ezabatua';
 $lang['created']               = 'sortua';
-$lang['restored']              = 'bertsio zaharra berrezarria';
+$lang['restored']              = 'bertsio zaharra berrezarria (%s)';
 $lang['external_edit']         = 'kanpoko aldaketa';
 $lang['summary']               = 'Aldatu laburpena';
 $lang['noflash']               = '<a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> beharrezkoa da eduki hau bistaratzeko.';
 $lang['download']              = 'Deskarga Snippet-a';
+$lang['tools']                 = 'Tresnak';
+$lang['user_tools']            = 'Erabiltzaile Tresnak';
+$lang['site_tools']            = 'Gune Tresnak';
+$lang['page_tools']            = 'Orri Tresnak';
+$lang['skip_to_content']       = 'edukira sahiestu';
+$lang['sidebar']               = 'Alboko-barra';
 $lang['mail_newpage']          = '[DokuWiki] gehitutako orria:';
 $lang['mail_changed']          = '[DokuWiki] aldatutako orria:';
 $lang['mail_subscribe_list']   = 'izen-espazioan aldatutako orriak:';
 $lang['mail_new_user']         = 'erabiltzaile berria:';
 $lang['mail_upload']           = 'fitxategia igota:';
+$lang['changes_type']          = '-ren aldaketak ikusi';
+$lang['pages_changes']         = 'Orriak';
+$lang['media_changes']         = 'Media fitxategiak';
+$lang['both_changes']          = 'Bai orriak nahiz media fitxategiak';
 $lang['qb_bold']               = 'Letra beltzez';
 $lang['qb_italic']             = 'Letra italiarrez';
 $lang['qb_underl']             = 'Azpimarratua';
@@ -217,6 +238,9 @@ $lang['img_copyr']             = 'Copyright';
 $lang['img_format']            = 'Formatua';
 $lang['img_camera']            = 'Kamera';
 $lang['img_keywords']          = 'Hitz-gakoak';
+$lang['img_width']             = 'Zabalera';
+$lang['img_height']            = 'Altuera';
+$lang['img_manager']           = 'Media kudeatzailean ikusi';
 $lang['subscr_subscribe_success'] = '%s gehitua %s-ren harpidetza zerrendara';
 $lang['subscr_subscribe_error'] = 'Errorea %s gehitzen %s-ren harpidetza zerrendara';
 $lang['subscr_subscribe_noaddress'] = 'Ez dago helbiderik zure login-arekin lotuta, ezin zara harpidetza zerrendara gehitua izan.';
@@ -235,6 +259,7 @@ $lang['subscr_style_digest']   = 'e-posta laburbildua orri bakoitzeko aldaketent
 $lang['subscr_style_list']     = 'aldatutako orrien zerrenda azken e-postatik (%.2f egunero)';
 $lang['authmodfailed']         = 'Erabiltzaile kautotzearen konfigurazioa okerra da. Mesedez, eman honen berri Wiki administratzaileari';
 $lang['authtempfail']          = 'Erabiltzaile kautotzea denboraldi batez ez dago erabilgarri. Egoerak hala jarraitzen badu, mesedez, eman honen berri Wiki administratzaileari';
+$lang['authpwdexpire']         = 'Zure pasahitza %d egun barru iraungiko da, laster aldatu beharko zenuke.';
 $lang['i_chooselang']          = 'Hautatu zure hizkuntza';
 $lang['i_installer']           = 'DokuWiki instalatzailea';
 $lang['i_wikiname']            = 'Wiki Izena';
@@ -249,29 +274,14 @@ $lang['i_confexists']          = '<code>%s</code> lehendik existitzen da';
 $lang['i_writeerr']            = 'Ezin da <code>%s</code> sortu. Direktorioaren/fitxategiaren baimenak egiaztatu eta sortu fitxategia eskuz.';
 $lang['i_badhash']             = 'aldatutakoa edo ezezaguna den dokuwiki.php (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - balioa arauen aurka edo hutsa';
-$lang['i_success']             = 'Konfigurazioa arrakastaz amaitu da. Orain, install.php fitxategia ezabatu dezakezu. Jarraitu ezazu <a href="doku.php">zure DokuWiki berrian</a>.';
-$lang['i_failure']             = 'Akats batzuk gertatu dira konfigurazio fitxategiak idazterakoan. Hauek eskuz konpondu beharra izan dezakezu <a href="doku.php">zure DokuWiki berria</a> erabili ahal izan aurretik.';
+$lang['i_success']             = 'Konfigurazioa arrakastaz amaitu da. Orain, install.php fitxategia ezabatu dezakezu. Jarraitu ezazu <a href="doku.php?id=wiki:welcome">zure DokuWiki berrian</a>.';
+$lang['i_failure']             = 'Akats batzuk gertatu dira konfigurazio fitxategiak idazterakoan. Hauek eskuz konpondu beharra izan dezakezu <a href="doku.php?id=wiki:welcome">zure DokuWiki berria</a> erabili ahal izan aurretik.';
 $lang['i_policy']              = 'Hasierako ACL politika';
 $lang['i_pol0']                = 'Wiki Irekia (irakurri, idatzi, fitxategiak igo edonorentzat)';
 $lang['i_pol1']                = 'Wiki Publikoa (irakurri edonorentzat, idatzi eta fitxategiak igo erregistratutako erabiltzaileentzat)';
 $lang['i_pol2']                = 'Wiki Itxia (irakurri, idatzi, fitxategiak igo erregistratutako erabiltzaileentzat soilik)';
 $lang['i_retry']               = 'Berriz saiatu';
 $lang['i_license']             = 'Mesedez, aukeratu zein lizentzipean ezarri nahi duzun zure edukia:';
-$lang['mu_intro']              = 'Hemen hainbat fitxategi aldi berean igo ditzakezu. Egin klik nabigazio botoian hauek ilarara gehitzeko. Sakatu igo botoia prest egotean.';
-$lang['mu_gridname']           = 'Fitxategi izena';
-$lang['mu_gridsize']           = 'Tamaina';
-$lang['mu_gridstat']           = 'Egoera';
-$lang['mu_namespace']          = 'Izen-espazioa';
-$lang['mu_browse']             = 'Nabigatu';
-$lang['mu_toobig']             = 'handiegia';
-$lang['mu_ready']              = 'igotzeko prest';
-$lang['mu_done']               = 'amaitua';
-$lang['mu_fail']               = 'hutsegitea';
-$lang['mu_authfail']           = 'saioa iraungita';
-$lang['mu_progress']           = '@PCT@% igota';
-$lang['mu_filetypes']          = 'Onartutako Fitxategi Motak';
-$lang['mu_info']               = 'igotako fitxategiak.';
-$lang['mu_lasterr']            = 'Azken errorea;';
 $lang['recent_global']         = 'Une honetan <b>%s</b> izen-espazioaren barneko aldaketak ikusten ari zara.<a href="%s"> Wiki osoaren azken aldaketak</a> ere ikusi ditzakezu.';
 $lang['years']                 = 'duela %d urte';
 $lang['months']                = 'duela %d hilabete';
@@ -281,3 +291,19 @@ $lang['hours']                 = 'duela %d ordu';
 $lang['minutes']               = 'duela %d minutu';
 $lang['seconds']               = 'duela %d segundu';
 $lang['wordblock']             = 'Zure aldaketa ez da aldatua izan blokeatutako testua (spam) daukalako.';
+$lang['media_uploadtab']       = 'Igo';
+$lang['media_searchtab']       = 'Bilatu';
+$lang['media_file']            = 'Fitxategia';
+$lang['media_viewtab']         = 'Begiratu';
+$lang['media_edittab']         = 'Editatu';
+$lang['media_historytab']      = 'Historia';
+$lang['media_sort_name']       = 'Izena';
+$lang['media_sort_date']       = 'Data';
+$lang['media_files']           = '%s -n fitxategiak';
+$lang['media_upload']          = 'Igo %s -ra';
+$lang['media_search']          = 'Bilatu %s -n';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s -n %s';
+$lang['media_edit']            = '%s editatu';
+$lang['media_update']          = 'Bertsio berria igo';
+$lang['media_restore']         = 'Bertsio hau berrezarri';
