@@ -42,7 +42,6 @@ $lang['btn_backtomedia']       = 'Povratak na Mediafile izbornik';
 $lang['btn_subscribe']         = 'Pretplati se na promjene dokumenta';
 $lang['btn_profile']           = 'Ažuriraj profil';
 $lang['btn_reset']             = 'Poništi promjene';
-$lang['btn_resendpwd']         = 'Pošalji novu lozinku';
 $lang['btn_draft']             = 'Uredi nacrt dokumenta';
 $lang['btn_recover']           = 'Vrati prijašnji nacrt dokumenta';
 $lang['btn_draftdel']          = 'Obriši nacrt dokumenta';
@@ -77,7 +76,6 @@ $lang['profnoempty']           = 'Prazno korisničko ime ili email nisu dopušte
 $lang['profchanged']           = 'Korisnički profil je uspješno izmijenjen.';
 $lang['pwdforget']             = 'Izgubili ste lozinku? Zatražite novu';
 $lang['resendna']              = 'Ovaj wiki ne podržava ponovno slanje lozinke emailom.';
-$lang['resendpwd']             = 'Poslati novu lozinku za';
 $lang['resendpwdmissing']      = 'Ispunite sva polja.';
 $lang['resendpwdnouser']       = 'Nije moguće pronaći korisnika.';
 $lang['resendpwdbadauth']      = 'Neispravan autorizacijski kod. Provjerite da li ste koristili potpun potvrdni link.';
@@ -167,7 +165,7 @@ $lang['lastmod']               = 'Zadnja izmjena';
 $lang['by']                    = 'od';
 $lang['deleted']               = 'obrisano';
 $lang['created']               = 'stvoreno';
-$lang['restored']              = 'vraćena prijašnja inačica';
+$lang['restored']              = 'vraćena prijašnja inačica (%s)';
 $lang['external_edit']         = 'vanjsko uređivanje';
 $lang['summary']               = 'Sažetak izmjena';
 $lang['noflash']               = 'Za prikazivanje ovog sadržaja potreban je <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>';
@@ -249,8 +247,8 @@ $lang['i_confexists']          = '<code>%s</code> već postoji';
 $lang['i_writeerr']            = 'Ne može se kreirati <code>%s</code>. Trebate provjeriti dozvole direktorija/datoteke i kreirati dokument ručno.';
 $lang['i_badhash']             = 'neprepoznat ili promijenjen dokuwiki.php (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - nedozvoljena ili prazna vrijednost';
-$lang['i_success']             = 'Konfiguracija je uspješno završena. Sada možete obrisati install.php datoteku. Nastavite na <a href="doku.php">vaš novi DokuWiki</a>.';
-$lang['i_failure']             = 'Pojavile su se neke greške prilikom pisanja konfiguracijskih datoteka. Morati ćete ih ručno ispraviti da bi mogli koristiti <a href="doku.php">vaš novi DokuWiki</a>.';
+$lang['i_success']             = 'Konfiguracija je uspješno završena. Sada možete obrisati install.php datoteku. Nastavite na <a href="doku.php?id=wiki:welcome">vaš novi DokuWiki</a>.';
+$lang['i_failure']             = 'Pojavile su se neke greške prilikom pisanja konfiguracijskih datoteka. Morati ćete ih ručno ispraviti da bi mogli koristiti <a href="doku.php?id=wiki:welcome">vaš novi DokuWiki</a>.';
 $lang['i_policy']              = 'Inicijalna ACL politika';
 $lang['i_pol0']                = 'Otvoreni Wiki (čitanje, pisanje, učitavanje za sve)';
 $lang['i_pol1']                = 'Javni Wiki (čitanje za sve, pisanje i učitavanje za registrirane korisnike)';
