@@ -43,7 +43,6 @@ $lang['btn_subscribe']         = 'Užsisakyti keitimų prenumeratą';
 $lang['btn_unsubscribe']       = 'Atsisakyti keitimų prenumeratos';
 $lang['btn_profile']           = 'Atnaujinti profilį';
 $lang['btn_reset']             = 'Atstata';
-$lang['btn_resendpwd']         = 'Išsiųsti naują slaptažodį';
 $lang['btn_draft']             = 'Redaguoti juodraštį';
 $lang['btn_recover']           = 'Atkurti juodraštį';
 $lang['btn_draftdel']          = 'Šalinti juodraštį';
@@ -77,7 +76,6 @@ $lang['profnoempty']           = 'Tuščias vardo arba el. pašto adreso laukas
 $lang['profchanged']           = 'Vartotojo profilis sėkmingai atnaujintas.';
 $lang['pwdforget']             = 'Pamiršote slaptažodį? Gaukite naują';
 $lang['resendna']              = 'Ši vikisvetainė neleidžia persiųsti slaptažodžių.';
-$lang['resendpwd']             = 'Atsiųsti naują slaptažodį';
 $lang['resendpwdmissing']      = 'Jūs turite užpildyti visus laukus.';
 $lang['resendpwdnouser']       = 'Tokio vartotojo nėra duomenų bazėje.';
 $lang['resendpwdbadauth']      = 'Atsiprašome, bet šis tapatybės nustatymo kodas netinkamas. Įsitikinkite, kad panaudojote pilną patvirtinimo nuorodą.';
@@ -91,7 +89,7 @@ $lang['txt_overwrt']           = 'Perrašyti egzistuojančią bylą';
 $lang['lockedby']              = 'Užrakintas vartotojo';
 $lang['lockexpire']            = 'Užraktas bus nuimtas';
 $lang['js']['willexpire']            = 'Šio puslapio redagavimo užrakto galiojimo laikas baigsis po minutės.\nNorėdami išvengti nesklandumų naudokite peržiūros mygtuką ir užraktas atsinaujins.';
-$lang['js']['notsavedyet']     = "Pakeitimai nebus išsaugoti.\nTikrai tęsti?";
+$lang['js']['notsavedyet']     = 'Pakeitimai nebus išsaugoti.\nTikrai tęsti?';
 $lang['rssfailed']             = 'Siunčiant šį feed\'ą įvyko klaida: ';
 $lang['nothingfound']          = 'Paieškos rezultatų nėra.';
 $lang['mediaselect']           = 'Mediabylos išsirinkimas';
@@ -134,7 +132,7 @@ $lang['lastmod']               = 'Keista';
 $lang['by']                    = 'vartotojo';
 $lang['deleted']               = 'ištrintas';
 $lang['created']               = 'sukurtas';
-$lang['restored']              = 'atstatyta sena versija';
+$lang['restored']              = 'atstatyta sena versija (%s)';
 $lang['external_edit']         = 'redaguoti papildomomis priemonėmis';
 $lang['summary']               = 'Redaguoti santrauką';
 $lang['noflash']               = '<a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> reikalingas šios medžiagos peržiūrai.';
