@@ -39,7 +39,7 @@ $lang['btn_backtomedia']       = 'Atpakaļ uz mēdiju failu izvēli';
 $lang['btn_subscribe']         = 'Abonēt izmaiņu paziņojumus';
 $lang['btn_profile']           = 'Labot savu profilu';
 $lang['btn_reset']             = 'Atsaukt izmaiņas';
-$lang['btn_resendpwd']         = 'Nosūtīt jaunu paroli';
+$lang['btn_resendpwd']         = 'Uzstādīt jaunu paroli';
 $lang['btn_draft']             = 'Labot melnrakstu';
 $lang['btn_recover']           = 'Atjaunot melnrakstu';
 $lang['btn_draftdel']          = 'Dzēst melnrakstu';
@@ -76,7 +76,7 @@ $lang['profnoempty']           = 'Bez vārda vai e-pasta adreses nevar.';
 $lang['profchanged']           = 'Profils veiksmīgi izlabots.';
 $lang['pwdforget']             = 'Aizmirsi paroli? Saņem jaunu';
 $lang['resendna']              = 'Paroļu izsūtīšanu nepiedāvāju.';
-$lang['resendpwd']             = 'Nosūtīt jaunu paroli lietotājam';
+$lang['resendpwd']             = 'Uzstādīt jaunu paroli lietotājam';
 $lang['resendpwdmissing']      = 'Atvaino, jāizpilda visas ailes.';
 $lang['resendpwdnouser']       = 'Atvaino, tāda lietotāja nav.';
 $lang['resendpwdbadauth']      = 'Atvaino, šis autorizācijas kods nav derīgs. Pārliecinies, ka lietoji pilnu apstiprināšanas adresi.';
@@ -89,6 +89,7 @@ $lang['searchmedia_in']        = 'Meklēt iekš %s';
 $lang['txt_upload']            = 'Norādi augšupielādējamo failu';
 $lang['txt_filename']          = 'Ievadi vikivārdu (nav obligāts)';
 $lang['txt_overwrt']           = 'Aizstāt esošo failu';
+$lang['maxuploadsize']         = 'Augšuplādējamā faila ierobežojums: %s.';
 $lang['lockedby']              = 'Patlaban bloķējis ';
 $lang['lockexpire']            = 'Bloķējums beigsies ';
 $lang['js']['willexpire']      = 'Tavs bloķējums uz šo lapu pēc minūtes beigsies.\nLai izvairītos no konflikta, nospied Iepriekšapskata pogu\n un bloķējuma laiku sāks skaitīt no jauna.';
@@ -127,10 +128,12 @@ $lang['js']['restore_confirm'] = 'Tiešām atjaunot šo versiju';
 $lang['js']['media_diff']      = 'Skatīt atšķirību';
 $lang['js']['media_diff_both'] = 'Blakus';
 $lang['js']['media_diff_opacity'] = 'Pārklāti';
+$lang['js']['media_diff_portions'] = 'Pa daļām';
 $lang['js']['media_select']    = 'Norādīt failus...';
 $lang['js']['media_upload_btn'] = 'Augšuplādēt';
 $lang['js']['media_done_btn']  = 'Gatavs';
 $lang['js']['media_drop']      = 'Nomet te augšuplādējamos failus';
+$lang['js']['media_cancel']    = 'atlikt';
 $lang['js']['media_overwrt']   = 'Rakstīt pāri esošajiem failiem';
 $lang['rssfailed']             = 'Kļūda saņemot saturu no ';
 $lang['nothingfound']          = 'Nekas nav atrasts.';
@@ -176,11 +179,17 @@ $lang['lastmod']               = 'Labota';
 $lang['by']                    = ', labojis';
 $lang['deleted']               = 'dzēsts';
 $lang['created']               = 'izveidots';
-$lang['restored']              = 'vecā versija atjaunota';
+$lang['restored']              = 'vecā versija atjaunota (%s)';
 $lang['external_edit']         = 'ārpussistēmas labojums';
 $lang['summary']               = 'Anotācija';
 $lang['noflash']               = 'Lai attēlotu lapas saturu, vajag <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>.';
 $lang['download']              = 'Lejuplādēt «kodiņu»((snippet))';
+$lang['tools']                 = 'Rīki';
+$lang['user_tools']            = 'Lietotāja rīki';
+$lang['site_tools']            = 'Vietnes rīki';
+$lang['page_tools']            = 'Lapas rīki';
+$lang['skip_to_content']       = 'uz rakstu';
+$lang['sidebar']               = 'Izvēlne';
 $lang['mail_newpage']          = 'lapa pievienota:';
 $lang['mail_changed']          = 'lapa mainīta:';
 $lang['mail_subscribe_list']   = 'Nodaļā mainītās lapas:';
@@ -251,6 +260,7 @@ $lang['subscr_style_digest']   = 'kopsavilkumu par katru lapu (reizi %.2f dienā
 $lang['subscr_style_list']     = 'kopš pēdējās vēstules notikušo labojumu sarakstu (reizi %.2f dienās)';
 $lang['authmodfailed']         = 'Aplami konfigurēta lietotāju autentifikācija. Lūdzu ziņo Wiki administratoram.';
 $lang['authtempfail']          = 'Lietotāju autentifikācija pašlaik nedarbojas. Ja tas turpinās ilgstoši, lūduz ziņo Wiki administratoram.';
+$lang['authpwdexpire']         = 'Tavai parolei pēc %d dienām biegsies termiņš, tā drīzumā jānomaina.';
 $lang['i_chooselang']          = 'Izvēlies valodu';
 $lang['i_installer']           = 'DokuWiki instalētājs';
 $lang['i_wikiname']            = 'Wiki vārds';
@@ -266,14 +276,17 @@ $lang['i_confexists']          = '<code>%s</code> jau ir';
 $lang['i_writeerr']            = 'Nevar izveidot <code>%s</code>. Jāpārbauda direktorijas/faila tiesības un fails jāizveido pašam.';
 $lang['i_badhash']             = 'nepazīstams vai izmainīts dokuwiki.php fails (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - neatļauta vai tukša vērtība';
-$lang['i_success']             = 'Konfigurēšana veiksmīgi pabeigta. Tagad vari nodzēst failu install.php. Tālāk turpini <a href="doku.php">savā jaunajā DokuWiki</a>.';
-$lang['i_failure']             = 'Rakstot konfigurācijas failu, gadījās dažas kļūmes. Pirms lieto <a href="doku.php">savu jauno DokuWiki</a>, tās varbūt jāizlabo.';
+$lang['i_success']             = 'Konfigurēšana veiksmīgi pabeigta. Tagad vari nodzēst failu install.php. Tālāk turpini <a href="doku.php?id=wiki:welcome">savā jaunajā DokuWiki</a>.';
+$lang['i_failure']             = 'Rakstot konfigurācijas failu, gadījās dažas kļūmes. Pirms lieto <a href="doku.php?id=wiki:welcome">savu jauno DokuWiki</a>, tās varbūt jāizlabo.';
 $lang['i_policy']              = 'Sākotnējā ACL politika';
 $lang['i_pol0']                = 'Atvērts Wiki (raksta, lasa un augšupielādē ikviens)';
 $lang['i_pol1']                = 'Publisks Wiki (lasa ikviens, raksta un augšupielādē reģistrēti lietotāji)';
 $lang['i_pol2']                = 'Slēgts Wiki (raksta, lasa un augšupielādē tikai reģistrēti lietotāji)';
 $lang['i_retry']               = 'Atkārtot';
 $lang['i_license']             = 'Ar kādu licenci saturs tiks publicēts:';
+$lang['i_license_none']        = 'Nerādīt nekādu licences informāciju';
+$lang['i_pop_field']           = 'Lūdzu palīdziet uzlabot DokuWiki';
+$lang['i_pop_label']           = 'Rezi mēnesī nosūtīt DokuWiki izstrādātājiem anonīmus lietošanas datus.';
 $lang['recent_global']         = 'Tu skati izmaiņas nodaļā <b>%s</b>. Ir iespējams <a href="%s">skatīt jaunākos grozījums visā viki</a>. ';
 $lang['years']                 = 'pirms %d gadiem';
 $lang['months']                = 'pirms %d mēnešiem';
@@ -306,4 +319,3 @@ $lang['media_perm_read']       = 'Atvainojiet, jums nav tiesību skatīt failus.
 $lang['media_perm_upload']     = 'Atvainojiet, jums nav tiesību augšupielādēt. ';
 $lang['media_update']          = 'Augšupielādēt jaunu versiju';
 $lang['media_restore']         = 'Atjaunot šo versiju';
-$lang['plugin_install_err']    = 'Modulis aplami instalēts.  Pārdēvē moduļa direktoriju %s par %s.';
