@@ -11,6 +11,9 @@
  * @author Leszek Stachowski <shazarre@gmail.com>
  * @author maros <dobrimaros@yahoo.pl>
  * @author Grzegorz Widła <dzesdzes@gmail.com>
+ * @author Łukasz Chmaj <teachmeter@gmail.com>
+ * @author Begina Felicysym <begina.felicysym@wp.eu>
+ * @author Aoi Karasu <aoikarasu@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -46,12 +49,14 @@ $lang['btn_backtomedia']       = 'Powrót do wyboru pliku';
 $lang['btn_subscribe']         = 'Subskrybuj zmiany';
 $lang['btn_profile']           = 'Aktualizuj profil';
 $lang['btn_reset']             = 'Resetuj';
-$lang['btn_resendpwd']         = 'Prześlij nowe hasło';
+$lang['btn_resendpwd']         = 'Podaj nowe hasło';
 $lang['btn_draft']             = 'Edytuj szkic';
 $lang['btn_recover']           = 'Przywróć szkic';
 $lang['btn_draftdel']          = 'Usuń szkic';
 $lang['btn_revert']            = 'Przywróć';
 $lang['btn_register']          = 'Zarejestruj się!';
+$lang['btn_apply']             = 'Zastosuj';
+$lang['btn_media']             = 'Menadżer multimediów';
 $lang['loggedinas']            = 'Zalogowany jako';
 $lang['user']                  = 'Użytkownik';
 $lang['pass']                  = 'Hasło';
@@ -81,7 +86,7 @@ $lang['profnoempty']           = 'Pusta nazwa lub adres e-mail nie dozwolone.';
 $lang['profchanged']           = 'Zaktualizowano profil użytkownika.';
 $lang['pwdforget']             = 'Nie pamiętasz hasła? Zdobądź nowe!';
 $lang['resendna']              = 'To wiki nie pozwala na powtórne przesyłanie hasła.';
-$lang['resendpwd']             = 'Prześlij nowe hasło dla';
+$lang['resendpwd']             = 'Podaj nowe hasło dla';
 $lang['resendpwdmissing']      = 'Wypełnij wszystkie pola.';
 $lang['resendpwdnouser']       = 'Nie można znaleźć tego użytkownika w bazie danych.';
 $lang['resendpwdbadauth']      = 'Błędny kod autoryzacji! Upewnij się, że użyłeś(aś) właściwego odnośnika.';
@@ -94,9 +99,10 @@ $lang['searchmedia_in']        = 'Szukaj w  %s';
 $lang['txt_upload']            = 'Wybierz plik do wysłania';
 $lang['txt_filename']          = 'Nazwa pliku (opcjonalnie)';
 $lang['txt_overwrt']           = 'Nadpisać istniejący plik?';
+$lang['maxuploadsize']         = 'Maksymalny rozmiar wysyłanych danych wynosi %s dla jednego pliku.';
 $lang['lockedby']              = 'Aktualnie zablokowane przez';
 $lang['lockexpire']            = 'Blokada wygasa';
-$lang['willexpire']            = 'Za minutę Twoja blokada tej strony wygaśnie.\nW celu uniknięcia konfliktów wyświetl podgląd aby odnowić blokadę.';
+$lang['js']['willexpire']      = 'Twoja blokada edycji tej strony wygaśnie w ciągu minuty. \nW celu uniknięcia konfliktów użyj przycisku podglądu aby odnowić blokadę.';
 $lang['js']['notsavedyet']     = 'Nie zapisane zmiany zostaną utracone.
 Czy na pewno kontynuować?';
 $lang['js']['searchmedia']     = 'Szukaj plików';
@@ -128,7 +134,17 @@ Możesz skopiować odnośnik.';
 $lang['js']['linkwiz']         = 'Tworzenie odnośników';
 $lang['js']['linkto']          = 'Link do';
 $lang['js']['del_confirm']     = 'Czy na pewno usunąć?';
-$lang['js']['mu_btn']          = 'Wyślij wiele plików na raz';
+$lang['js']['restore_confirm'] = 'Naprawdę przywrócić tą wersję?';
+$lang['js']['media_diff']      = 'Pokaż różnice:';
+$lang['js']['media_diff_both'] = 'Obok siebie';
+$lang['js']['media_diff_opacity'] = 'Przezroczystość';
+$lang['js']['media_diff_portions'] = 'Przesunięcie';
+$lang['js']['media_select']    = 'Wybierz pliki...';
+$lang['js']['media_upload_btn'] = 'Przesłanie plików';
+$lang['js']['media_done_btn']  = 'Zrobione';
+$lang['js']['media_drop']      = 'Upuść tutaj pliki do przesłania';
+$lang['js']['media_cancel']    = 'usuń';
+$lang['js']['media_overwrt']   = 'Nadpisz istniejące pliki';
 $lang['rssfailed']             = 'Wystąpił błąd przy pobieraniu tych danych: ';
 $lang['nothingfound']          = 'Nic nie znaleziono.';
 $lang['mediaselect']           = 'Wysyłanie pliku';
@@ -163,6 +179,9 @@ $lang['yours']                 = 'Twoja wersja';
 $lang['diff']                  = 'Pokaż różnice między wersjami';
 $lang['diff2']                 = 'Pokaż różnice między zaznaczonymi wersjami';
 $lang['difflink']              = 'Odnośnik do tego porównania';
+$lang['diff_type']             = 'Zobacz różnice:';
+$lang['diff_inline']           = 'W linii';
+$lang['diff_side']             = 'Jeden obok drugiego';
 $lang['line']                  = 'Linia';
 $lang['breadcrumb']            = 'Ślad';
 $lang['youarehere']            = 'Jesteś tutaj';
@@ -170,16 +189,25 @@ $lang['lastmod']               = 'ostatnio zmienione';
 $lang['by']                    = 'przez';
 $lang['deleted']               = 'usunięto';
 $lang['created']               = 'utworzono';
-$lang['restored']              = 'przywrócono poprzednią wersję';
+$lang['restored']              = 'przywrócono poprzednią wersję (%s)';
 $lang['external_edit']         = 'edycja zewnętrzna';
 $lang['summary']               = 'Opis zmian';
 $lang['noflash']               = 'Plugin <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> jest niezbędny do obejrzenia tej zawartości.';
 $lang['download']              = 'Pobierz zrzut';
+$lang['tools']                 = 'Narzędzia';
+$lang['user_tools']            = 'Narzędzia użytkownika';
+$lang['site_tools']            = 'Narzędzia witryny';
+$lang['page_tools']            = 'Narzędzia strony';
+$lang['skip_to_content']       = 'przejście do zawartości';
 $lang['mail_newpage']          = 'Strona dodana:';
 $lang['mail_changed']          = 'Strona zmieniona:';
 $lang['mail_subscribe_list']   = 'Zmienione strony w katalogu:';
 $lang['mail_new_user']         = 'Nowy użytkownik:';
 $lang['mail_upload']           = 'Umieszczono plik:';
+$lang['changes_type']          = 'Zobacz zmiany';
+$lang['pages_changes']         = 'Strony';
+$lang['media_changes']         = 'Pliki multimediów';
+$lang['both_changes']          = 'Zarówno strony jak i pliki multimediów';
 $lang['qb_bold']               = 'Pogrubienie';
 $lang['qb_italic']             = 'Pochylenie';
 $lang['qb_underl']             = 'Podkreślenie';
@@ -220,6 +248,9 @@ $lang['img_copyr']             = 'Prawa autorskie';
 $lang['img_format']            = 'Format';
 $lang['img_camera']            = 'Aparat';
 $lang['img_keywords']          = 'Słowa kluczowe';
+$lang['img_width']             = 'Szerokość';
+$lang['img_height']            = 'Wysokość';
+$lang['img_manager']           = 'Zobacz w menadżerze multimediów';
 $lang['subscr_subscribe_success'] = 'Dodano %s do listy subskrypcji %s';
 $lang['subscr_subscribe_error'] = 'Błąd podczas dodawania %s do listy subskrypcji %s';
 $lang['subscr_subscribe_noaddress'] = 'Brak adresu skojarzonego z twoim loginem, nie możesz zostać dodany(a) do listy subskrypcji';
@@ -234,10 +265,9 @@ $lang['subscr_m_unsubscribe']  = 'Zrezygnuj z subskrypcji';
 $lang['subscr_m_subscribe']    = 'Subskrybuj';
 $lang['subscr_m_receive']      = 'Otrzymuj';
 $lang['subscr_style_every']    = 'email przy każdej zmianie';
-$lang['subscr_style_digest']   = 'email ze streszczeniem zmian dla każdej ze stron';
-$lang['subscr_style_list']     = 'lista zmienionych stron od czasu ostatniego emaila';
 $lang['authmodfailed']         = 'Błąd uwierzytelnienia. Powiadom administratora tego wiki.';
 $lang['authtempfail']          = 'Uwierzytelnienie użytkownika jest w tej chwili niemożliwe. Jeśli ta sytuacja się powtórzy, powiadom administratora tego wiki.';
+$lang['authpwdexpire']         = 'Twoje hasło wygaśnie za %d dni. Należy je zmienić w krótkim czasie.';
 $lang['i_chooselang']          = 'Wybierz język';
 $lang['i_installer']           = 'Instalator DokuWiki';
 $lang['i_wikiname']            = 'Nazwa Wiki';
@@ -253,29 +283,14 @@ $lang['i_confexists']          = '<code>%s</code> już istnieje';
 $lang['i_writeerr']            = 'Nie można utworzyć <code>%s</code>. Sprawdź uprawnienia do katalogu lub pliku i stwórz plik ręcznie.';
 $lang['i_badhash']             = 'nierozpoznany lub zmodyfikowany plik dokuwiki.php (skrót=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - nieprawidłowa wartość lub jej brak';
-$lang['i_success']             = 'Konfiguracja pomyślnie zakończona. Możesz teraz usunąć plik install.php. Przejdź do <a href="doku.php">Twojego nowego DokuWiki</a>.';
-$lang['i_failure']             = 'Podczas zapisu plików konfiguracyjnych wystąpiły błędy. Musisz usunąć wszystkie problemy, zanim zaczniesz korzystać z <a href="doku.php">Twojego nowego DokuWiki</a>.';
+$lang['i_success']             = 'Konfiguracja pomyślnie zakończona. Możesz teraz usunąć plik install.php. Przejdź do <a href="doku.php?id=wiki:welcome">Twojego nowego DokuWiki</a>.';
+$lang['i_failure']             = 'Podczas zapisu plików konfiguracyjnych wystąpiły błędy. Musisz usunąć wszystkie problemy, zanim zaczniesz korzystać z <a href="doku.php?id=wiki:welcome">Twojego nowego DokuWiki</a>.';
 $lang['i_policy']              = 'Wstępna polityka uprawnień ACL';
 $lang['i_pol0']                = 'Otwarte Wiki (odczyt, zapis i dodawanie plików dla wszystkich)';
 $lang['i_pol1']                = 'Publiczne Wiki (odczyt dla wszystkich, zapis i dodawanie plików tylko dla zarejestrowanych użytkowników)';
 $lang['i_pol2']                = 'Zamknięte Wiki (odczyt, zapis i dodawanie plików tylko dla zarejestrowanych użytkowników)';
 $lang['i_retry']               = 'Spróbuj ponownie';
 $lang['i_license']             = 'Wybierz licencję, na warunkach której chcesz udostępniać treści:';
-$lang['mu_intro']              = 'Możesz tutaj wysłać wiele plików na raz. Kliknij przycisk "Przeglądaj" aby dodać je do kolejki. Kliknij "Wyślij" gdy skończysz.';
-$lang['mu_gridname']           = 'Nazwa pliku';
-$lang['mu_gridsize']           = 'Rozmiar';
-$lang['mu_gridstat']           = 'Stan';
-$lang['mu_namespace']          = 'Katalog';
-$lang['mu_browse']             = 'Przeglądaj';
-$lang['mu_toobig']             = 'za duży';
-$lang['mu_ready']              = 'gotowy do wysłania';
-$lang['mu_done']               = 'zakończono';
-$lang['mu_fail']               = 'nie powiodło się';
-$lang['mu_authfail']           = 'sesja wygasła';
-$lang['mu_progress']           = '@PCT@% wysłano';
-$lang['mu_filetypes']          = 'Dozwolone typy plików';
-$lang['mu_info']               = 'wysłanych plików.';
-$lang['mu_lasterr']            = 'Ostatni błąd:';
 $lang['recent_global']         = 'W tej chwili przeglądasz zmiany w katalogu <b>%s</b>. Możesz przejrzeć także <a href="%s">zmiany w całym wiki</a>.';
 $lang['years']                 = '%d lat temu';
 $lang['months']                = '%d miesięcy temu';
@@ -285,3 +300,26 @@ $lang['hours']                 = '%d godzin temu';
 $lang['minutes']               = '%d minut temu';
 $lang['seconds']               = '%d sekund temu';
 $lang['wordblock']             = 'Twoje ustawienia nie zostały zapisane ponieważ zawierają niedozwoloną treść (spam).';
+$lang['media_uploadtab']       = 'Przesyłanie plików';
+$lang['media_searchtab']       = 'Szukaj';
+$lang['media_file']            = 'Plik';
+$lang['media_viewtab']         = 'Widok';
+$lang['media_edittab']         = 'Zmiana';
+$lang['media_historytab']      = 'Historia';
+$lang['media_list_thumbs']     = 'Miniatury';
+$lang['media_list_rows']       = 'Wiersze';
+$lang['media_sort_name']       = 'Nazwa';
+$lang['media_sort_date']       = 'Data';
+$lang['media_namespaces']      = 'Wybierz przestrzeń nazw';
+$lang['media_files']           = 'Pliki w %s';
+$lang['media_upload']          = 'Przesyłanie plików na %s';
+$lang['media_search']          = 'Znajdź w %s';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s na %s';
+$lang['media_edit']            = 'Zmień %s';
+$lang['media_history']         = 'Historia dla %s';
+$lang['media_meta_edited']     = 'zmienione metadane';
+$lang['media_perm_read']       = 'Przepraszamy, nie masz wystarczających uprawnień do odczytu plików.';
+$lang['media_perm_upload']     = 'Przepraszamy, nie masz wystarczających uprawnień do przesyłania plików.';
+$lang['media_update']          = 'Prześlij nową wersję';
+$lang['media_restore']         = 'Odtwórz tą wersję';
