@@ -19,15 +19,16 @@
  * @author Aleksandr Selivanov <alexgearbox@gmail.com>
  * @author Ladyko Andrey <fylh@succexy.spb.ru>
  * @author Eugene <windy.wanderer@gmail.com>
+ * @author Johnny Utah <pcpa@cyberpunk.su>
+ * @author Ivan I. Udovichenko (sendtome@mymailbox.pp.ua)
  */
 $lang['encoding']              = ' utf-8';
 $lang['direction']             = 'ltr';
-$lang['doublequoteopening']    = '«'; //&ldquo;
-$lang['doublequoteclosing']    = '»'; //&rdquo;
-$lang['singlequoteopening']    = '„'; //&lsquo;
-$lang['singlequoteclosing']    = '“'; //&rsquo;
-$lang['apostrophe']            = '’'; //&rsquo;
-
+$lang['doublequoteopening']    = '«';
+$lang['doublequoteclosing']    = '»';
+$lang['singlequoteopening']    = '„';
+$lang['singlequoteclosing']    = '“';
+$lang['apostrophe']            = '’';
 $lang['btn_edit']              = 'Править страницу';
 $lang['btn_source']            = 'Показать исходный текст';
 $lang['btn_show']              = 'Показать страницу';
@@ -55,7 +56,7 @@ $lang['btn_backtomedia']       = 'Вернуться к выбору медиа
 $lang['btn_subscribe']         = 'Подписаться (все правки)';
 $lang['btn_profile']           = 'Профиль';
 $lang['btn_reset']             = 'Сброс';
-$lang['btn_resendpwd']         = 'Выслать новый пароль';
+$lang['btn_resendpwd']         = 'Установить новый пароль';
 $lang['btn_draft']             = 'Править черновик';
 $lang['btn_recover']           = 'Восстановить черновик';
 $lang['btn_draftdel']          = 'Удалить черновик';
@@ -63,7 +64,6 @@ $lang['btn_revert']            = 'Восстановить';
 $lang['btn_register']          = 'Зарегистрироваться';
 $lang['btn_apply']             = 'Применить';
 $lang['btn_media']             = 'Media Manager';
-
 $lang['loggedinas']            = 'Зашли как';
 $lang['user']                  = 'Логин';
 $lang['pass']                  = 'Пароль';
@@ -78,7 +78,6 @@ $lang['badlogin']              = 'Извините, неверное имя по
 $lang['minoredit']             = 'Небольшие изменения';
 $lang['draftdate']             = 'Черновик сохранён';
 $lang['nosecedit']             = 'За это время страница была изменена и информация о секции устарела. Загружена полная версия страницы.';
-
 $lang['regmissing']            = 'Извините, вам следует заполнить все поля.';
 $lang['reguexists']            = 'Извините, пользователь с таким логином уже существует.';
 $lang['regsuccess']            = 'Пользователь создан, пароль выслан на адрес электронной почты.';
@@ -88,32 +87,29 @@ $lang['regbadmail']            = 'Данный вами адрес электр
 $lang['regbadpass']            = 'Два введённых пароля не идентичны. Пожалуйста, попробуйте ещё раз.';
 $lang['regpwmail']             = 'Ваш пароль для системы «ДокуВики»';
 $lang['reghere']               = 'У вас ещё нет аккаунта? Зарегистрируйтесь';
-
 $lang['profna']                = 'Данная вики не поддерживает изменение профиля';
 $lang['profnochange']          = 'Изменений не было внесено, профиль не обновлён.';
 $lang['profnoempty']           = 'Логин и адрес электронной почты не могут быть пустыми.';
 $lang['profchanged']           = 'Профиль пользователя успешно обновлён.';
-
 $lang['pwdforget']             = 'Забыли пароль? Получите новый';
 $lang['resendna']              = 'Данная вики не поддерживает повторную отправку пароля.';
-$lang['resendpwd']             = 'Выслать пароль для';
+$lang['resendpwd']             = 'Установить новый пароль для';
 $lang['resendpwdmissing']      = 'Вы должны заполнить все поля формы.';
 $lang['resendpwdnouser']       = 'Пользователь с таким логином не обнаружен в нашей базе данных.';
 $lang['resendpwdbadauth']      = 'Извините, неверный код авторизации. Убедитесь, что вы полностью скопировали ссылку. ';
 $lang['resendpwdconfirm']      = 'Ссылка для подтверждения пароля была выслана по электронной почте. ';
 $lang['resendpwdsuccess']      = 'Ваш новый пароль был выслан по электронной почте.';
-
 $lang['license']               = 'За исключением случаев, когда указано иное, содержимое этой вики предоставляется на условиях следующей лицензии:';
 $lang['licenseok']             = 'Примечание: редактируя эту страницу, вы соглашаетесь на использование своего вклада на условиях следующей лицензии:';
-
 $lang['searchmedia']           = 'Поиск по имени файла:';
 $lang['searchmedia_in']        = 'Поиск в %s';
 $lang['txt_upload']            = 'Выберите файл для загрузки';
 $lang['txt_filename']          = 'Введите имя файла в вики (необязательно)';
 $lang['txt_overwrt']           = 'Перезаписать существующий файл';
+$lang['maxuploadsize']         = 'Максимальный размер загружаемого файла %s';
 $lang['lockedby']              = 'В данный момент заблокирован';
 $lang['lockexpire']            = 'Блокировка истекает в';
-$lang['js']['willexpire']      = 'Ваша блокировка редактирования этой страницы истекает в течение минуты.\nЧтобы избежать конфликтов и сбросить таймер блокировки, нажмите кнопку просмотра.';
+$lang['js']['willexpire']      = 'Ваша блокировка этой страницы на редактирование истекает в течении минуты.\nЧтобы предотвратить конфликты используйте кнопку "Просмотр" для сброса таймера блокировки.';
 $lang['js']['notsavedyet']     = 'Несохранённые изменения будут потеряны. Вы действительно хотите продолжить?';
 $lang['js']['searchmedia']     = 'Поиск файлов';
 $lang['js']['keepopen']        = 'Не закрывать окно после выбора';
@@ -143,22 +139,19 @@ $lang['js']['nosmblinks']      = 'Ссылка на сетевые катало
 $lang['js']['linkwiz']         = 'Мастер ссылок';
 $lang['js']['linkto']          = 'Ссылка на:';
 $lang['js']['del_confirm']     = 'Вы на самом деле желаете удалить выбранное?';
-$lang['js']['willexpire']      = 'Ваша блокировка этой страницы на редактирование истекает в течении минуты.\nЧтобы предотвратить конфликты используйте кнопку "Просмотр" для сброса таймера блокировки.';
-$lang['js']['restore_confirm']     = 'Действительно восстановить эту версию?';
-$lang['js']['media_diff']          = 'Просмотр отличий:';
-$lang['js']['media_diff_both']     = 'Рядом';
-$lang['js']['media_diff_opacity']  = 'Наложением';
+$lang['js']['restore_confirm'] = 'Действительно восстановить эту версию?';
+$lang['js']['media_diff']      = 'Просмотр отличий:';
+$lang['js']['media_diff_both'] = 'Рядом';
+$lang['js']['media_diff_opacity'] = 'Наложением';
 $lang['js']['media_diff_portions'] = 'Частями';
-$lang['js']['media_select']        = 'Выбрать файлы…';
-$lang['js']['media_upload_btn']    = 'Загрузить';
-$lang['js']['media_done_btn']      = 'Готово';
-$lang['js']['media_drop']          = 'Переместите файлы сюда для загрузки';
-$lang['js']['media_cancel']        = 'отменить';
-$lang['js']['media_overwrt']       = 'Перезаписать существующие файлы';
-
+$lang['js']['media_select']    = 'Выбрать файлы…';
+$lang['js']['media_upload_btn'] = 'Загрузить';
+$lang['js']['media_done_btn']  = 'Готово';
+$lang['js']['media_drop']      = 'Переместите файлы сюда для загрузки';
+$lang['js']['media_cancel']    = 'отменить';
+$lang['js']['media_overwrt']   = 'Перезаписать существующие файлы';
 $lang['rssfailed']             = 'Произошла ошибка при получении следующей новостной ленты: ';
 $lang['nothingfound']          = 'Ничего не найдено.';
-
 $lang['mediaselect']           = 'Выбор медиафайла';
 $lang['fileupload']            = 'Загрузка медиафайла';
 $lang['uploadsucc']            = 'Загрузка произведена успешно';
@@ -183,7 +176,6 @@ $lang['mediaextchange']        = 'Расширение изменилось: с
 $lang['reference']             = 'Ссылки для';
 $lang['ref_inuse']             = 'Этот файл не может быть удалён, так как он используется на следующих страницах:';
 $lang['ref_hidden']            = 'Некоторые ссылки находятся на страницах, на чтение которых у вас нет прав доступа';
-
 $lang['hits']                  = 'соответствий';
 $lang['quickhits']             = 'Соответствия в названиях страниц';
 $lang['toc']                   = 'Содержание';
@@ -202,23 +194,26 @@ $lang['lastmod']               = 'Последние изменения';
 $lang['by']                    = ' —';
 $lang['deleted']               = 'удалено';
 $lang['created']               = 'создано';
-$lang['restored']              = 'старая ревизия восстановлена';
+$lang['restored']              = 'старая ревизия восстановлена (%s)';
 $lang['external_edit']         = 'внешнее изменение';
 $lang['summary']               = 'Сводка изменений';
 $lang['noflash']               = 'Для просмотра этого содержимого требуется <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>.';
 $lang['download']              = 'Скачать код';
-
+$lang['tools']                 = 'Инструменты';
+$lang['user_tools']            = 'Инструменты пользователя';
+$lang['site_tools']            = 'Инструменты сайта';
+$lang['page_tools']            = 'Инструменты страницы';
+$lang['skip_to_content']       = 'Перейти к содержанию';
+$lang['sidebar']               = 'Боковая колонна';
 $lang['mail_newpage']          = 'страница добавлена:';
 $lang['mail_changed']          = 'страница изменена:';
 $lang['mail_subscribe_list']   = 'изменились страницы в пространстве имён:';
 $lang['mail_new_user']         = 'новый пользователь:';
 $lang['mail_upload']           = 'файл закачан:';
-
 $lang['changes_type']          = 'Посмотреть изменения';
 $lang['pages_changes']         = 'Страниц';
 $lang['media_changes']         = 'Медиа файлов';
 $lang['both_changes']          = 'И страниц и медиа файлов';
-
 $lang['qb_bold']               = 'Полужирный';
 $lang['qb_italic']             = 'Курсив';
 $lang['qb_underl']             = 'Подчёркнутый';
@@ -243,11 +238,8 @@ $lang['qb_media']              = 'Добавить изображения или
 $lang['qb_sig']                = 'Вставить подпись';
 $lang['qb_smileys']            = 'Смайлики';
 $lang['qb_chars']              = 'Специальные символы';
-
 $lang['upperns']               = 'Перейти в родительское пространство имён';
-
 $lang['admin_register']        = 'Добавить пользователя';
-
 $lang['metaedit']              = 'Править метаданные';
 $lang['metasaveerr']           = 'Ошибка записи метаданных';
 $lang['metasaveok']            = 'Метаданные сохранены';
@@ -265,30 +257,25 @@ $lang['img_keywords']          = 'Ключевые слова';
 $lang['img_width']             = 'Ширина';
 $lang['img_height']            = 'Высота';
 $lang['img_manager']           = 'Просмотр в media manager';
-
-$lang['subscr_subscribe_success']   = 'Добавлен %s в подписку на %s';
-$lang['subscr_subscribe_error']     = 'Невозможно добавить %s в подписку на %s';
+$lang['subscr_subscribe_success'] = 'Добавлен %s в подписку на %s';
+$lang['subscr_subscribe_error'] = 'Невозможно добавить %s в подписку на %s';
 $lang['subscr_subscribe_noaddress'] = 'Нет адреса электронной почты, сопоставленного с вашей учётной записью. Вы не можете подписаться на рассылку';
 $lang['subscr_unsubscribe_success'] = 'Удалён %s из подписки на %s';
-$lang['subscr_unsubscribe_error']   = 'Ошибка удаления %s из подписки на %s';
-$lang['subscr_already_subscribed']  = '%s уже подписан на %s';
-$lang['subscr_not_subscribed']      = '%s не подписан на %s';
-// Manage page for subscriptions
-$lang['subscr_m_not_subscribed']    = 'Вы не подписаны на текущую страницу или пространство имён.';
-$lang['subscr_m_new_header']        = 'Добавить подписку';
-$lang['subscr_m_current_header']    = 'Текущие подписки';
-$lang['subscr_m_unsubscribe']       = 'Отменить подписку';
-$lang['subscr_m_subscribe']         = 'Подписаться';
-$lang['subscr_m_receive']           = 'Получить';
-$lang['subscr_style_every']         = 'уведомлять о каждом изменении';
-$lang['subscr_style_digest']        = 'сводка изменений по каждой странице';
-$lang['subscr_style_list']          = 'перечислять изменившиеся страницы с прошлого уведомления';
-
-/* auth.class language support */
+$lang['subscr_unsubscribe_error'] = 'Ошибка удаления %s из подписки на %s';
+$lang['subscr_already_subscribed'] = '%s уже подписан на %s';
+$lang['subscr_not_subscribed'] = '%s не подписан на %s';
+$lang['subscr_m_not_subscribed'] = 'Вы не подписаны на текущую страницу или пространство имён.';
+$lang['subscr_m_new_header']   = 'Добавить подписку';
+$lang['subscr_m_current_header'] = 'Текущие подписки';
+$lang['subscr_m_unsubscribe']  = 'Отменить подписку';
+$lang['subscr_m_subscribe']    = 'Подписаться';
+$lang['subscr_m_receive']      = 'Получить';
+$lang['subscr_style_every']    = 'уведомлять о каждом изменении';
+$lang['subscr_style_digest']   = 'информационное электронное письмо со списком изменений для каждоый страницы (каждые %.2f дней)';
+$lang['subscr_style_list']     = 'список изменённых страниц со времени последнего отправленного электронного письма (каждые %.2f дней)';
 $lang['authmodfailed']         = 'Неправильная конфигурация аутентификации пользователя. Пожалуйста, сообщите об этом своему администратору вики.';
 $lang['authtempfail']          = 'Аутентификация пользователей временно недоступна. Если проблема продолжается какое-то время, пожалуйста, сообщите об этом своему администратору вики.';
-
-/* installer strings */
+$lang['authpwdexpire']         = 'Действие вашего пароля истекает через %d дней. Вы должны изменить его как можно скорее';
 $lang['i_chooselang']          = 'Выберите свой язык/Choose your language';
 $lang['i_installer']           = 'Установка «ДокуВики»';
 $lang['i_wikiname']            = 'Название вики';
@@ -306,15 +293,17 @@ $lang['i_writeerr']            = 'Не удалось создать <code>%s</c
 $lang['i_badhash']             = 'dokuwiki.php не распознан или изменён (хэш=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> — недопустимое или пустое значение';
 $lang['i_success']             = 'Конфигурация прошла успешно. Теперь вы можете удалить файл install.php. Переходите к
-                                 <a href="doku.php">своей новой «ДокуВики»</a>.';
-$lang['i_failure']             = 'При записи в файлы конфигурации были обнаружены ошибки. Возможно, вам придётся исправить их вручную, прежде чем вы сможете использовать <a href="doku.php">свою новую «ДокуВики»</a>.';
+                                 <a href="doku.php?id=wiki:welcome">своей новой «ДокуВики»</a>.';
+$lang['i_failure']             = 'При записи в файлы конфигурации были обнаружены ошибки. Возможно, вам придётся исправить их вручную, прежде чем вы сможете использовать <a href="doku.php?id=wiki:welcome">свою новую «ДокуВики»</a>.';
 $lang['i_policy']              = 'Исходная политика прав доступа';
 $lang['i_pol0']                = 'Открытая вики (чтение, запись, закачка файлов для всех)';
 $lang['i_pol1']                = 'Общедоступная вики (чтение для всех, запись и загрузка файлов для зарегистрированных пользователей)';
 $lang['i_pol2']                = 'Закрытая вики (чтение, запись и загрузка файлов только для зарегистрированных пользователей)';
 $lang['i_retry']               = 'Повторить попытку';
 $lang['i_license']             = 'Пожалуйста, выберите тип лицензии для своей вики:';
-
+$lang['i_license_none']        = 'Не отображать информацию о лицензионных операциях';
+$lang['i_pop_field']           = 'Пожалуйста, помогите нам улучшить DokuWiki:';
+$lang['i_pop_label']           = 'Отправлять раз в месяц анонимную пользовательскую информацию разработчикам DokuWiki';
 $lang['recent_global']         = 'Вы просматриваете изменения в пространстве имён <b>%s</b>. Вы можете также <a href="%s">просмотреть недавние изменения во всей вики</a>.';
 $lang['years']                 = '%d лет назад';
 $lang['months']                = '%d месяц(ев) назад';
@@ -323,24 +312,28 @@ $lang['days']                  = '%d дней назад';
 $lang['hours']                 = '%d час(ов) назад';
 $lang['minutes']               = '%d минут назад';
 $lang['seconds']               = '%d секунд назад';
-
 $lang['wordblock']             = 'Ваши изменения не сохранены, поскольку они содержат блокируемые слова (спам).';
-
 $lang['media_uploadtab']       = 'Загрузка';
 $lang['media_searchtab']       = 'Поиск';
+$lang['media_file']            = 'Файл';
 $lang['media_viewtab']         = 'Просмотр';
 $lang['media_edittab']         = 'Правка';
 $lang['media_historytab']      = 'История';
+$lang['media_list_thumbs']     = 'Миниатюры';
+$lang['media_list_rows']       = 'Строки';
 $lang['media_sort_name']       = 'Сортировка по имени';
 $lang['media_sort_date']       = 'Сортировка по дате';
+$lang['media_namespaces']      = 'Выберите каталог';
+$lang['media_files']           = 'Файлы в %s';
 $lang['media_upload']          = 'Загрузка в пространство имён <strong>%s</strong>.';
 $lang['media_search']          = 'Поиск в пространстве имён <strong>%s</strong>.';
 $lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s в %s
+';
 $lang['media_edit']            = 'Правка %s';
+$lang['media_history']         = 'История %s';
 $lang['media_meta_edited']     = 'метаданные изменены';
 $lang['media_perm_read']       = 'Извините, у Вас недостаточно прав для чтения файлов.';
 $lang['media_perm_upload']     = 'Извините, у Вас недостаточно прав для загрузки файлов.';
 $lang['media_update']          = 'Загрузить новую версию';
 $lang['media_restore']         = 'Восстановить эту версию';
-
-$lang['plugin_install_err']    = "Плагин установлен некорректно. Переименуйте папку плагина из '%s' в '%s'.";
