@@ -52,7 +52,6 @@ $lang['btn_backtomedia']       = 'Tillbaka till val av Mediafil';
 $lang['btn_subscribe']         = 'Prenumerera på ändringar';
 $lang['btn_profile']           = 'Uppdatera profil';
 $lang['btn_reset']             = 'Återställ';
-$lang['btn_resendpwd']         = 'Skicka nytt lösenord';
 $lang['btn_draft']             = 'Redigera utkast';
 $lang['btn_recover']           = 'Återskapa utkast';
 $lang['btn_draftdel']          = 'Radera utkast';
@@ -87,7 +86,6 @@ $lang['profnoempty']           = 'Namn och e-postadress måste fyllas i.';
 $lang['profchanged']           = 'Användarprofilen uppdaterad.';
 $lang['pwdforget']             = 'Glömt ditt lösenord? Ordna ett nytt';
 $lang['resendna']              = 'Den här wikin stödjer inte utskick av lösenord.';
-$lang['resendpwd']             = 'Skicka nytt lösenord för';
 $lang['resendpwdmissing']      = 'Du måste fylla i alla fält.';
 $lang['resendpwdnouser']       = 'Den här användaren hittas inte i databasen.';
 $lang['resendpwdbadauth']      = 'Den här verifieringskoden är inte giltig. Kontrollera att du använde hela verifieringslänken.';
@@ -174,7 +172,7 @@ $lang['lastmod']               = 'Senast uppdaterad';
 $lang['by']                    = 'av';
 $lang['deleted']               = 'raderad';
 $lang['created']               = 'skapad';
-$lang['restored']              = 'tidigare version återställd';
+$lang['restored']              = 'tidigare version återställd (%s)';
 $lang['external_edit']         = 'extern redigering';
 $lang['summary']               = 'Redigeringskommentar';
 $lang['noflash']               = '<a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> behövs för att visa detta innehåll.';
@@ -248,9 +246,9 @@ $lang['i_writeerr']            = 'Kan inte skapa <code>%s</code>. Kontrollera fi
 $lang['i_badhash']             = 'okänd eller ändrad dokuwiki.php (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - felaktig eller blank';
 $lang['i_success']             = 'Konfigurationen avslutades utan fel. Du kan radera filen install.php nu. Fortsätt till
-                        <a href="doku.php">din nya DokuWiki</a>.';
+                        <a href="doku.php?id=wiki:welcome">din nya DokuWiki</a>.';
 $lang['i_failure']             = 'Fel uppstod vid skrivning av konfigurationsfilerna. Du kan behöva ordna till dem manuellt innan
-                         du kan använda <a href="doku.php">din nya DokuWiki</a>.';
+                         du kan använda <a href="doku.php?id=wiki:welcome">din nya DokuWiki</a>.';
 $lang['i_policy']              = 'Initial ACL-policy';
 $lang['i_pol0']                = 'Öppen wiki (alla får läsa, skriva och ladda upp filer)';
 $lang['i_pol1']                = 'Publik wiki (alla får läsa, registrerade användare för skriva och ladda upp filer)';
