@@ -2,10 +2,19 @@
 /**
  * Chinese(Simplified) language file
  *
- * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html) 
+ * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  * @author ZDYX <zhangduyixiong@gmail.com>
  * @author http://www.chinese-tools.com/tools/converter-tradsimp.html
- * @author George Sheraton guxd@163.com
+ * @author George Sheraton <guxd@163.com>
+ * @author Simon zhan <simonzhan@21cn.com>
+ * @author mr.jinyi@gmail.com
+ * @author ben <ben@livetom.com>
+ * @author lainme <lainme993@gmail.com>
+ * @author caii <zhoucaiqi@gmail.com>
+ * @author Hiphen Lee <jacob.b.leung@gmail.com>
+ * @author caii, patent agent in China <zhoucaiqi@gmail.com>
+ * @author lainme993@gmail.com
+ * @author Shuo-Ting Jian <shoting@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -28,7 +37,7 @@ $lang['btn_revs']              = '修订记录';
 $lang['btn_recent']            = '最近更改';
 $lang['btn_upload']            = '上传';
 $lang['btn_cancel']            = '取消';
-$lang['btn_index']             = '索引';
+$lang['btn_index']             = '网站地图';
 $lang['btn_secedit']           = '编辑';
 $lang['btn_login']             = '登录';
 $lang['btn_logout']            = '退出';
@@ -39,15 +48,16 @@ $lang['btn_back']              = '返回';
 $lang['btn_backlink']          = '反向链接';
 $lang['btn_backtomedia']       = '返回到媒体文件选择工具';
 $lang['btn_subscribe']         = '订阅本页更改';
-$lang['btn_unsubscribe']       = '退订本页更改';
-$lang['btn_subscribens']       = '订阅命名空间更改';
-$lang['btn_unsubscribens']     = '退订命名空间更改';
 $lang['btn_profile']           = '更新个人信息';
 $lang['btn_reset']             = '重设';
-$lang['btn_resendpwd']         = '发送新密码';
+$lang['btn_resendpwd']         = '设置新密码';
 $lang['btn_draft']             = '编辑草稿';
 $lang['btn_recover']           = '恢复草稿';
 $lang['btn_draftdel']          = '删除草稿';
+$lang['btn_revert']            = '恢复';
+$lang['btn_register']          = '注册';
+$lang['btn_apply']             = '应用';
+$lang['btn_media']             = '媒体管理器';
 $lang['loggedinas']            = '登录为';
 $lang['user']                  = '用户名';
 $lang['pass']                  = '密码';
@@ -57,10 +67,9 @@ $lang['passchk']               = '请再输一次';
 $lang['remember']              = '记住我';
 $lang['fullname']              = '全名';
 $lang['email']                 = 'E-Mail';
-$lang['register']              = '注册';
 $lang['profile']               = '用户信息';
 $lang['badlogin']              = '对不起，用户名或密码错误。';
-$lang['minoredit']             = '轻微修改';
+$lang['minoredit']             = '细微修改';
 $lang['draftdate']             = '草稿自动保存于';
 $lang['nosecedit']             = '在您编辑期间本页刚被他人修改过，局部信息已过期，故载入全页。';
 $lang['regmissing']            = '对不起，您必须填写所有的区域。';
@@ -78,7 +87,7 @@ $lang['profnoempty']           = '不允许使用空的用户名或邮件地址
 $lang['profchanged']           = '用户信息更新成功。';
 $lang['pwdforget']             = '忘记密码？立即获取新密码';
 $lang['resendna']              = '本维基不支持二次发送密码。';
-$lang['resendpwd']             = '发送新密码给';
+$lang['resendpwd']             = '设置新密码用于';
 $lang['resendpwdmissing']      = '对不起，您必须填写所有的区域。';
 $lang['resendpwdnouser']       = '对不起，在我们的用户数据中找不到该用户。';
 $lang['resendpwdbadauth']      = '对不起，该认证码错误。请使用完整的确认链接。';
@@ -86,13 +95,57 @@ $lang['resendpwdconfirm']      = '确认链接已经通过邮件发送给您了
 $lang['resendpwdsuccess']      = '您的新密码已经通过邮件发送给您了。';
 $lang['license']               = '除额外注明的地方外，本维基上的内容按下列许可协议发布：';
 $lang['licenseok']             = '当您选择开始编辑本页，即寓示你同意将你贡献的内容按下列许可协议发布：';
+$lang['searchmedia']           = '查找文件名：';
+$lang['searchmedia_in']        = '在%s中查找';
 $lang['txt_upload']            = '选择要上传的文件';
 $lang['txt_filename']          = '上传并重命名为（可选）';
 $lang['txt_overwrt']           = '覆盖已存在的同名文件';
+$lang['maxuploadsize']         = '上传限制。每个文件 %s';
 $lang['lockedby']              = '目前已被下列人员锁定';
 $lang['lockexpire']            = '预计锁定解除于';
-$lang['willexpire']            = '您对本页的独有编辑权将于一分钟之后解除。\n为了防止与其他人的编辑冲突，请使用预览按钮重设计时器。';
-$lang['notsavedyet']           = '未保存的更改将丢失。\n真的要继续？';
+$lang['js']['willexpire']      = '您对本页的独有编辑权将于一分钟之后解除。\n为了防止与其他人的编辑冲突，请使用预览按钮重设计时器。';
+$lang['js']['notsavedyet']     = '未保存的更改将丢失。
+真的要继续？';
+$lang['js']['searchmedia']     = '查找文件';
+$lang['js']['keepopen']        = '选中后不自动关闭窗口';
+$lang['js']['hidedetails']     = '隐藏详细信息';
+$lang['js']['mediatitle']      = '链接设置';
+$lang['js']['mediadisplay']    = '链接类型';
+$lang['js']['mediaalign']      = '对齐';
+$lang['js']['mediasize']       = '图片大小';
+$lang['js']['mediatarget']     = '链接目标';
+$lang['js']['mediaclose']      = '关闭';
+$lang['js']['mediainsert']     = '插入';
+$lang['js']['mediadisplayimg'] = '显示图片。';
+$lang['js']['mediadisplaylnk'] = '仅显示链接。';
+$lang['js']['mediasmall']      = '小尺寸';
+$lang['js']['mediamedium']     = '中等尺寸';
+$lang['js']['medialarge']      = '大尺寸';
+$lang['js']['mediaoriginal']   = '原始版本';
+$lang['js']['medialnk']        = '到详细页面的链接';
+$lang['js']['mediadirect']     = '到原始文件的直接链接';
+$lang['js']['medianolnk']      = '没有链接';
+$lang['js']['medianolink']     = '不要链接图片';
+$lang['js']['medialeft']       = '左对齐图片。';
+$lang['js']['mediaright']      = '右对齐图片。';
+$lang['js']['mediacenter']     = '居中对齐图片。';
+$lang['js']['medianoalign']    = '不使用对齐。';
+$lang['js']['nosmblinks']      = '连接到 Windows 共享功能只有在 IE 浏览器中才能正常使用。
+但您仍能复制并粘贴该链接。';
+$lang['js']['linkwiz']         = '链接向导';
+$lang['js']['linkto']          = '链接到：';
+$lang['js']['del_confirm']     = '真的要删除选中的项目吗？';
+$lang['js']['restore_confirm'] = '确实要恢复这个版本么？';
+$lang['js']['media_diff']      = '查看差异：';
+$lang['js']['media_diff_both'] = '肩并肩';
+$lang['js']['media_diff_opacity'] = '叠加';
+$lang['js']['media_diff_portions'] = '滑块';
+$lang['js']['media_select']    = '选择文件……';
+$lang['js']['media_upload_btn'] = '上传';
+$lang['js']['media_done_btn']  = '完成';
+$lang['js']['media_drop']      = '拖拽文件到此处来上传';
+$lang['js']['media_cancel']    = '删除';
+$lang['js']['media_overwrt']   = '覆盖已存在的文件';
 $lang['rssfailed']             = '获取该 RSS 信息时产生错误：';
 $lang['nothingfound']          = '什么都没有找到。';
 $lang['mediaselect']           = '媒体文件';
@@ -110,11 +163,7 @@ $lang['deletefail']            = '无法删除“%s”- 请检查权限。';
 $lang['mediainuse']            = '文件“%s”无法删除 - 它正被使用中。';
 $lang['namespaces']            = '命名空间';
 $lang['mediafiles']            = '可用的文件';
-$lang['js']['keepopen']        = '选中后不自动关闭窗口';
-$lang['js']['hidedetails']     = '隐藏详细信息';
-$lang['js']['nosmblinks']      = '连接到 Windows 共享功能只有在 IE 浏览器中才能正常使用。
-但您仍能复制并粘贴该链接。';
-$lang['js']['mu_btn']          = '一次上传了多个文件';
+$lang['accessdenied']          = '您没有权限浏览此页面。';
 $lang['mediausage']            = '使用下列字符链接到该文件：';
 $lang['mediaview']             = '查看该文件';
 $lang['mediaroot']             = '根目录';
@@ -130,6 +179,10 @@ $lang['current']               = '当前版本';
 $lang['yours']                 = '您的版本';
 $lang['diff']                  = '显示与当前版本的差别';
 $lang['diff2']                 = '显示跟目前版本的差异';
+$lang['difflink']              = '到此差别页面的链接';
+$lang['diff_type']             = '查看差异：';
+$lang['diff_inline']           = '行内显示';
+$lang['diff_side']             = '并排显示';
 $lang['line']                  = '行';
 $lang['breadcrumb']            = '您的足迹';
 $lang['youarehere']            = '您在这里';
@@ -137,15 +190,26 @@ $lang['lastmod']               = '最后更改';
 $lang['by']                    = '由';
 $lang['deleted']               = '移除';
 $lang['created']               = '创建';
-$lang['restored']              = '已恢复为旧版';
+$lang['restored']              = '已恢复为旧版 (%s)';
 $lang['external_edit']         = '外部编辑';
 $lang['summary']               = '编辑摘要';
 $lang['noflash']               = '需要 <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash 插件</a> 来播放本内容。 ';
+$lang['download']              = '下载片段';
+$lang['tools']                 = '工具';
+$lang['user_tools']            = '用户工具';
+$lang['site_tools']            = '站点工具';
+$lang['page_tools']            = '页面工具';
+$lang['skip_to_content']       = '跳至内容';
+$lang['sidebar']               = '侧边栏';
 $lang['mail_newpage']          = '添加页面：';
 $lang['mail_changed']          = '更改页面：';
+$lang['mail_subscribe_list']   = '命名空间中改变的页面：';
 $lang['mail_new_user']         = '新用户：';
 $lang['mail_upload']           = '已上传的文件：';
-$lang['qb_alert']              = '请输入您想格式化的文字。\n它将会被附加到文件的最后。';
+$lang['changes_type']          = '查看何种更改';
+$lang['pages_changes']         = '页面';
+$lang['media_changes']         = '媒体文件';
+$lang['both_changes']          = '页面和媒体文件';
 $lang['qb_bold']               = '粗体';
 $lang['qb_italic']             = '斜体';
 $lang['qb_underl']             = '下划线';
@@ -156,6 +220,11 @@ $lang['qb_h2']                 = '标题 H2 ';
 $lang['qb_h3']                 = '标题 H3';
 $lang['qb_h4']                 = '标题 H4';
 $lang['qb_h5']                 = '标题 H5';
+$lang['qb_h']                  = '标题';
+$lang['qb_hs']                 = '选择标题';
+$lang['qb_hplus']              = '上级标题';
+$lang['qb_hminus']             = '下级标题';
+$lang['qb_hequal']             = '同级标题';
 $lang['qb_link']               = '内部链接';
 $lang['qb_extlink']            = '外部链接';
 $lang['qb_hr']                 = '水平线';
@@ -165,7 +234,7 @@ $lang['qb_media']              = '插入图像或其他文件';
 $lang['qb_sig']                = '插入签名';
 $lang['qb_smileys']            = '表情符号';
 $lang['qb_chars']              = '特殊字符';
-$lang['del_confirm']           = '真的要删除选中的项目吗？';
+$lang['upperns']               = '跳转到父级名空间';
 $lang['admin_register']        = '添加新用户';
 $lang['metaedit']              = '编辑元数据';
 $lang['metasaveerr']           = '写入元数据失败';
@@ -181,13 +250,28 @@ $lang['img_copyr']             = '版权';
 $lang['img_format']            = '格式';
 $lang['img_camera']            = '相机';
 $lang['img_keywords']          = '关键字';
-$lang['subscribe_success']     = '已将 %s 成功添加到 %s 的订阅列表';
-$lang['subscribe_error']       = '无法将 %s 添加到 %s 的订阅列表';
-$lang['subscribe_noaddress']   = '您的登录信息中不包含电子邮件地址，您无法加入订阅列表';
-$lang['unsubscribe_success']   = '已将 %s 从 %s 的订阅列表中成功删除';
-$lang['unsubscribe_error']     = '无法将 %s 从 %s 的订阅列表中删除';
+$lang['img_width']             = '宽度';
+$lang['img_height']            = '高度';
+$lang['img_manager']           = '在媒体管理器中查看';
+$lang['subscr_subscribe_success'] = '添加 %s 到 %s 的订阅列表';
+$lang['subscr_subscribe_error'] = '添加 %s 到 %s 的订阅列表中出现错误';
+$lang['subscr_subscribe_noaddress'] = '没有与您登录信息相关联的地址，您无法被添加到订阅列表';
+$lang['subscr_unsubscribe_success'] = '%s 被移出 %s 的订阅列表';
+$lang['subscr_unsubscribe_error'] = '%s 被移出 %s 的订阅列表中出现错误';
+$lang['subscr_already_subscribed'] = '%s 已经订阅了 %s';
+$lang['subscr_not_subscribed'] = '%s 没有订阅 %s';
+$lang['subscr_m_not_subscribed'] = '您现在没有订阅当前页面或者命名空间。';
+$lang['subscr_m_new_header']   = '添加订阅';
+$lang['subscr_m_current_header'] = '当前订阅';
+$lang['subscr_m_unsubscribe']  = '退订';
+$lang['subscr_m_subscribe']    = '订阅';
+$lang['subscr_m_receive']      = '接收';
+$lang['subscr_style_every']    = '对每次更改发送邮件';
+$lang['subscr_style_digest']   = '对每个页面发送更改的摘要邮件（每 %.2f 天）';
+$lang['subscr_style_list']     = '自上封邮件以来更改的页面的列表（每 %.2f 天）';
 $lang['authmodfailed']         = '错误的用户认证设置。请通知维基管理员。';
 $lang['authtempfail']          = '用户认证暂时无法使用。如果该状态一直存在，请通知维基管理员。';
+$lang['authpwdexpire']         = '您的密码将在 %d 天内过期，请尽快更改';
 $lang['i_chooselang']          = '选择您的语言';
 $lang['i_installer']           = 'DokuWiki 安装工具';
 $lang['i_wikiname']            = '维基名称';
@@ -205,25 +289,47 @@ $lang['i_writeerr']            = '无法创建 <code>%s</code>。您需要检查
 $lang['i_badhash']             = '无法识别的或被修改的 dokuwiki.php（值=<code>%s</code>）';
 $lang['i_badval']              = '<code>%s</code> - 非法或空值';
 $lang['i_success']             = '配置成功完成。您现在可以删除 install.php 了。继续进入
-                        <a href="doku.php">您全新的 DokuWiki</a>。';
-$lang['i_failure']             = '写入配置文件的时候产生一些错误。在使用 <a href="doku.php">您全新安装的 DokuWiki</a> 前
+                        <a href="doku.php?id=wiki:welcome">您全新的 DokuWiki</a>。';
+$lang['i_failure']             = '写入配置文件的时候产生一些错误。在使用 <a href="doku.php?id=wiki:welcome">您全新安装的 DokuWiki</a> 前
                          您需要手动修复它们。';
 $lang['i_policy']              = '初始的 ACL 政策';
 $lang['i_pol0']                = '开放的维基（任何人都有读、写、上传的权限）';
 $lang['i_pol1']                = '公共的维基（任何人都有读的权限，只有注册用户才有写和上传的权限）';
 $lang['i_pol2']                = '关闭的维基（只有注册用户才有读、写、上传的权限）';
 $lang['i_retry']               = '重试';
-$lang['mu_intro']              = '您可以在此一次上传多个文件。点按浏览按钮添加文件到上传队列中，先好后按上传钮。';
-$lang['mu_gridname']           = '文件名';
-$lang['mu_gridsize']           = '大小';
-$lang['mu_gridstat']           = '状态';
-$lang['mu_namespace']          = '名称空间';
-$lang['mu_browse']             = '浏览';
-$lang['mu_toobig']             = '过大';
-$lang['mu_ready']              = '准备好上传';
-$lang['mu_done']               = '完成';
-$lang['mu_fail']               = '失败';
-$lang['mu_authfail']           = '会话过期';
-$lang['mu_progress']           = '@PCT@% 上传完成';
-$lang['mu_filetypes']          = '允许的文件类型';
+$lang['i_license']             = '请选择您希望的内容发布许可协议：';
+$lang['i_license_none']        = '不要显示任何许可协议信息';
+$lang['i_pop_field']           = '请帮助我们改进 Dokuwiki 的体验：';
+$lang['i_pop_label']           = '每个月向 Dokuwiki 开发者发送匿名的使用数据';
 $lang['recent_global']         = '您当前看到的是<b>%s</b> 名称空间的变动。你还可以在<a href="%s">查看整个维基的近期变动</a>。';
+$lang['years']                 = '%d年前';
+$lang['months']                = '%d月前';
+$lang['weeks']                 = '%d周前';
+$lang['days']                  = '%d天前';
+$lang['hours']                 = '%d小时前';
+$lang['minutes']               = '%d分钟前';
+$lang['seconds']               = '%d秒前';
+$lang['wordblock']             = '您的更改没有被保存，因为它包含被屏蔽的文字（垃圾信息）。';
+$lang['media_uploadtab']       = '上传';
+$lang['media_searchtab']       = '搜索';
+$lang['media_file']            = '文件';
+$lang['media_viewtab']         = '查看';
+$lang['media_edittab']         = '编辑';
+$lang['media_historytab']      = '历史';
+$lang['media_list_thumbs']     = '缩图';
+$lang['media_list_rows']       = '列表';
+$lang['media_sort_name']       = '按名称';
+$lang['media_sort_date']       = '按日期';
+$lang['media_namespaces']      = '选择命名空间';
+$lang['media_files']           = '在 %s 中的文件';
+$lang['media_upload']          = '上传到 <strong>%s</strong> 命名空间。';
+$lang['media_search']          = '在 <strong>%s</strong> 命名空间中搜索。';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s 在 %s';
+$lang['media_edit']            = '编辑 %s';
+$lang['media_history']         = '%s 的历史纪录';
+$lang['media_meta_edited']     = '元数据已编辑';
+$lang['media_perm_read']       = '抱歉，您没有足够权限读取这些文件。';
+$lang['media_perm_upload']     = '抱歉，您没有足够权限来上传文件。';
+$lang['media_update']          = '上传新版本';
+$lang['media_restore']         = '恢复这个版本';
