@@ -9,6 +9,12 @@
  * @author Diego Pierotto ita.translations@tiscali.it
  * @author ita.translations@tiscali.it
  * @author Lorenzo Breda <lbreda@gmail.com>
+ * @author snarchio@alice.it
+ * @author robocap <robocap1@gmail.com>
+ * @author Osman Tekin osman.tekin93@hotmail.it
+ * @author Jacopo Corbetta <jacopo.corbetta@gmail.com>
+ * @author Matteo Pasotti <matteo@xquiet.eu>
+ * @author snarchio@gmail.com
  */
 $lang['admin_acl']             = 'Gestione Lista Controllo Accessi (ACL)';
 $lang['acl_group']             = 'Gruppo';
@@ -21,11 +27,11 @@ $lang['p_user_id']             = 'L\'utente <b class="acluser">%s</b> attualment
 $lang['p_user_ns']             = 'L\'utente <b class="acluser">%s</b> attualmente ha i seguenti permessi per la categoria <b class="aclns">%s</b>: <i>%s</i>.';
 $lang['p_group_id']            = 'I membri del gruppo<b class="aclgroup">%s</b> attualmente hanno i seguenti permessi sulla pagina <b class="aclpage">%s</b>: <i>%s</i>.';
 $lang['p_group_ns']            = 'I membri del gruppo<b class="aclgroup">%s</b> attualmente hanno i seguenti permessi per la categoria <b class="aclns">%s</b>: <i>%s</i>.';
-$lang['p_choose_id']           = 'Per favore <b>inserisci un utente o gruppo</b> nel campo sopra per modificare i permessi impostati per la pagina <b class="aclpage">%s</b>.';
-$lang['p_choose_ns']           = 'Per favore <b>inserisci un utente o un gruppo</b> nel campo sopra per modificare i permessi impostati per la categoria <b class="aclns">%s</b>.';
-$lang['p_inherited']           = 'Nota: Questi permessi non sono stati esplicitamente impostati, ma sono stati ereditati da altri gruppi o da categorie superiori.';
-$lang['p_isadmin']             = 'Nota: Il gruppo o utente selezionato ha sempre tutti i permessi perché è configurato come amministratore.';
-$lang['p_include']             = 'I permessi più elevati includono i permessi inferiori. I permessi di Creazione, Upload e Cancellazione si applicano soltanto alle categorie e non alle pagine.';
+$lang['p_choose_id']           = '<b>Inserisci un utente o gruppo</b> nel campo sopra per modificare i permessi impostati per la pagina <b class="aclpage">%s</b>.';
+$lang['p_choose_ns']           = '<b>Inserisci un utente o un gruppo</b> nel campo sopra per modificare i permessi impostati per la categoria <b class="aclns">%s</b>.';
+$lang['p_inherited']           = 'Nota: questi permessi non sono stati esplicitamente impostati, ma sono stati ereditati da altri gruppi o da categorie superiori.';
+$lang['p_isadmin']             = 'Nota: il gruppo o utente selezionato ha sempre tutti i permessi perché è configurato come amministratore.';
+$lang['p_include']             = 'I permessi più elevati includono i permessi inferiori. I permessi Crea, Carica ed Elimina si applicano soltanto alle categorie e non alle pagine.';
 $lang['current']               = 'Regole ACL attuali';
 $lang['where']                 = 'Pagina/Categoria';
 $lang['who']                   = 'Utente/Gruppo';
@@ -33,8 +39,8 @@ $lang['perm']                  = 'Permessi';
 $lang['acl_perm0']             = 'Nessuno';
 $lang['acl_perm1']             = 'Lettura';
 $lang['acl_perm2']             = 'Modifica';
-$lang['acl_perm4']             = 'Creazione';
-$lang['acl_perm8']             = 'Upload';
-$lang['acl_perm16']            = 'Cancellazione';
-$lang['acl_new']               = 'Aggiungi nuovo record';
-$lang['acl_mod']               = 'Modifica record';
+$lang['acl_perm4']             = 'Crea';
+$lang['acl_perm8']             = 'Carica';
+$lang['acl_perm16']            = 'Elimina';
+$lang['acl_new']               = 'Aggiungi nuovo valore';
+$lang['acl_mod']               = 'Modifica valore';
