@@ -1,7 +1,7 @@
 <?php
 /**
  * Info Plugin: Displays information about various DokuWiki internals
- * 
+ *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  * @author     Andreas Gohr <andi@splitbrain.org>
  * @author     Esther Brunner <wikidesign@gmail.com>
@@ -9,36 +9,19 @@
 // must be run within Dokuwiki
 if(!defined('DOKU_INC')) die();
 
-if(!defined('DOKU_PLUGIN')) define('DOKU_PLUGIN',DOKU_INC.'lib/plugins/');
-require_once(DOKU_PLUGIN.'syntax.php');
-
 /**
  * All DokuWiki plugins to extend the parser/rendering mechanism
  * need to inherit from this class
  */
 class syntax_plugin_info extends DokuWiki_Syntax_Plugin {
 
-    /**
-     * return some info
-     */
-    function getInfo(){
-        return array(
-            'author' => 'Andreas Gohr',
-            'email'  => 'andi@splitbrain.org',
-            'date'   => '2006-12-09',
-            'name'   => 'Info Plugin',
-            'desc'   => 'Displays information about various DokuWiki internals',
-            'url'    => 'http://wiki.splitbrain.org/plugin:info',
-        );
-    }
-
     /**
      * What kind of syntax are we?
      */
     function getType(){
         return 'substition';
     }
-   
+
     /**
      * What about paragraphs?
      */
@@ -48,7 +31,7 @@ class syntax_plugin_info extends DokuWiki_Syntax_Plugin {
 
     /**
      * Where to sort in?
-     */ 
+     */
     function getSort(){
         return 155;
     }
@@ -77,9 +60,6 @@ class syntax_plugin_info extends DokuWiki_Syntax_Plugin {
         if($format == 'xhtml'){
             //handle various info stuff
             switch ($data[0]){
-                case 'version':
-                    $renderer->doc .= getVersion();
-                    break;
                 case 'syntaxmodes':
                     $renderer->doc .= $this->_syntaxmodes_xhtml();
                     break;
@@ -117,15 +97,22 @@ class syntax_plugin_info extends DokuWiki_Syntax_Plugin {
      *
      * uses some of the original renderer methods
      */
-    function _plugins_xhtml($type, &$renderer){
+    function _plugins_xhtml($type, Doku_Renderer &$renderer){
         global $lang;
         $renderer->doc .= '<ul>';
 
         $plugins = plugin_list($type);
+        $plginfo = array();
+
+        // remove subparts
         foreach($plugins as $p){
             if (!$po =& plugin_load($type,$p)) continue;
-            $info = $po->getInfo();
+            list($name,$part) = explode('_',$p,2);
+            $plginfo[$name] = $po->getInfo();
+        }
 
+        // list them
+        foreach($plginfo as $info){
             $renderer->doc .= '<li><div class="li">';
             $renderer->externallink($info['url'],$info['name']);
             $renderer->doc .= ' ';
@@ -142,23 +129,23 @@ class syntax_plugin_info extends DokuWiki_Syntax_Plugin {
 
         $renderer->doc .= '</ul>';
     }
-    
+
     /**
      * list all installed plugins
      *
      * uses some of the original renderer methods
      */
-    function _helpermethods_xhtml(&$renderer){
+    function _helpermethods_xhtml(Doku_Renderer &$renderer){
         global $lang;
-        
+
         $plugins = plugin_list('helper');
         foreach($plugins as $p){
             if (!$po =& plugin_load('helper',$p)) continue;
-            
+
             if (!method_exists($po, 'getMethods')) continue;
             $methods = $po->getMethods();
             $info = $po->getInfo();
-            
+
             $hid = $this->_addToTOC($info['name'], 2, $renderer);
             $doc = '<h2><a name="'.$hid.'" id="'.$hid.'">'.hsc($info['name']).'</a></h2>';
             $doc .= '<div class="level2">';
@@ -170,7 +157,7 @@ class syntax_plugin_info extends DokuWiki_Syntax_Plugin {
                 $hid = $this->_addToTOC($title, 3, $renderer);
                 $doc .= '<h3><a name="'.$hid.'" id="'.$hid.'">'.hsc($title).'</a></h3>';
                 $doc .= '<div class="level3">';
-                $doc .= '<table class="inline"><tbody>';
+                $doc .= '<div class="table"><table class="inline"><tbody>';
                 $doc .= '<tr><th>Description</th><td colspan="2">'.$method['desc'].
                     '</td></tr>';
                 if ($method['params']){
@@ -186,11 +173,11 @@ class syntax_plugin_info extends DokuWiki_Syntax_Plugin {
                     $doc .= '<tr><th>Return value</th><td>'.hsc(key($method['return'])).
                         '</td><td>'.hsc(current($method['return'])).'</td></tr>';
                 }
-                $doc .= '</tbody></table>';
+                $doc .= '</tbody></table></div>';
                 $doc .= '</div>';
             }
             unset($po);
-            
+
             $renderer->doc .= $doc;
         }
     }
@@ -202,7 +189,7 @@ class syntax_plugin_info extends DokuWiki_Syntax_Plugin {
         global $PARSER_MODES;
         $doc  = '';
 
-        $doc .= '<table class="inline"><tbody>';
+        $doc .= '<div class="table"><table class="inline"><tbody>';
         foreach($PARSER_MODES as $mode => $modes){
             $doc .= '<tr>';
             $doc .= '<td class="leftalign">';
@@ -213,7 +200,7 @@ class syntax_plugin_info extends DokuWiki_Syntax_Plugin {
             $doc .= '</td>';
             $doc .= '</tr>';
         }
-        $doc .= '</tbody></table>';
+        $doc .= '</tbody></table></div>';
         return $doc;
     }
 
@@ -229,24 +216,24 @@ class syntax_plugin_info extends DokuWiki_Syntax_Plugin {
         }
         return $doc;
     }
-    
+
     /**
      * Adds a TOC item
      */
-    function _addToTOC($text, $level, &$renderer){
+    function _addToTOC($text, $level, Doku_Renderer_xhtml &$renderer){
         global $conf;
-        
-        if (($level >= $conf['toptoclevel']) && ($level <= $conf['maxtoclevel'])){ 
-            $hid  = $renderer->_headerToLink($text, 'true'); 
-            $renderer->toc[] = array( 
-                'hid'   => $hid, 
-                'title' => $text, 
-                'type'  => 'ul', 
-                'level' => $level - $conf['toptoclevel'] + 1 
+
+        if (($level >= $conf['toptoclevel']) && ($level <= $conf['maxtoclevel'])){
+            $hid  = $renderer->_headerToLink($text, 'true');
+            $renderer->toc[] = array(
+                'hid'   => $hid,
+                'title' => $text,
+                'type'  => 'ul',
+                'level' => $level - $conf['toptoclevel'] + 1
             );
         }
         return $hid;
     }
 }
 
-//Setup VIM: ex: et ts=4 enc=utf-8 :
+//Setup VIM: ex: et ts=4 :
