@@ -16,10 +16,14 @@
  * @author Johan Guilbaud <guilbaud.johan@gmail.com>
  * @author schplurtz@laposte.net
  * @author skimpax@gmail.com
+ * @author Yannick Aure <yannick.aure@gmail.com>
+ * @author Olivier DUVAL <zorky00@gmail.com>
+ * @author Anael Mobilia <contrib@anael.eu>
+ * @author Bruno Veilleux <bruno.vey@gmail.com>
  */
 $lang['menu']                  = 'Gestion des utilisateurs';
-$lang['noauth']                = '(authentification utilisateur non disponible)';
-$lang['nosupport']             = '(gestion utilisateur non supportée)';
+$lang['noauth']                = '(authentification de l\'utilisateur non disponible)';
+$lang['nosupport']             = '(gestion de l\'utilisateur non supportée)';
 $lang['badauth']               = 'mécanisme d\'authentification invalide';
 $lang['user_id']               = 'Identifiant ';
 $lang['user_pass']             = 'Mot de passe ';
@@ -38,20 +42,20 @@ $lang['search']                = 'Rechercher';
 $lang['search_prompt']         = 'Effectuer la recherche';
 $lang['clear']                 = 'Réinitialiser la recherche';
 $lang['filter']                = 'Filtre';
-$lang['summary']               = 'Affichage des utilisateurs %1$d-%2$d parmi %3$d trouvé(s). %4$d utilisateur(s) au total.';
-$lang['nonefound']             = 'Aucun utilisateur trouvé. %d utilisateur(s) au total.';
+$lang['summary']               = 'Affichage des utilisateurs %1$d-%2$d parmi %3$d trouvés. %4$d utilisateurs au total.';
+$lang['nonefound']             = 'Aucun utilisateur trouvé. %d utilisateurs au total.';
 $lang['delete_ok']             = '%d utilisateurs effacés';
-$lang['delete_fail']           = '%d effacement échoué.';
+$lang['delete_fail']           = '%d effacements échoués.';
 $lang['update_ok']             = 'Utilisateur mis à jour avec succès';
-$lang['update_fail']           = 'Échec de la mise à jour utilisateur';
-$lang['update_exists']         = 'Échec du changement de nom d\'utilisateur, le nom spécifié (%s) existe déjà (toutes les autres modifications seront effectuées).';
-$lang['start']                 = 'Démarrage';
+$lang['update_fail']           = 'Échec lors de la mise à jour de l\'utilisateur';
+$lang['update_exists']         = 'Échec lors du changement du nom d\'utilisateur : le nom spécifié (%s) existe déjà (toutes les autres modifications seront effectuées).';
+$lang['start']                 = 'Début';
 $lang['prev']                  = 'Précédent';
 $lang['next']                  = 'Suivant';
-$lang['last']                  = 'Dernier';
+$lang['last']                  = 'Fin';
 $lang['edit_usermissing']      = 'Utilisateur sélectionné non trouvé, cet utilisateur a peut-être été supprimé ou modifié ailleurs.';
 $lang['user_notify']           = 'Notifier l\'utilisateur ';
-$lang['note_notify']           = 'Envoi de notification par courriel uniquement lorsqu\'un nouveau mot de passe est attribué à l\'utilisateur.';
+$lang['note_notify']           = 'Expédition de notification par courriel uniquement lorsque l\'utilisateur fourni un nouveau mot de passe.';
 $lang['note_group']            = 'Les nouveaux utilisateurs seront ajoutés au groupe par défaut (%s) si aucun groupe n\'est spécifié.';
 $lang['note_pass']             = 'Le mot de passe sera généré automatiquement si le champ est laissé vide et si la notification de l\'utilisateur est activée.';
 $lang['add_ok']                = 'Utilisateur ajouté avec succès';
